@@ -458,6 +458,17 @@ class AcrMockCommandsTests(unittest.TestCase):
             timeout=300,
             verify=mock.ANY)
 
+        # Test https strip
+        acr_manifest_show(cmd,
+                          manifest_id=['https://testregistry.azurecr.io/testrepository:testtag'])
+        mock_requests_get.assert_called_with(
+            method='get',
+            url='https://testregistry.azurecr.io/v2/testrepository/manifests/sha256:c5515758d4c5e1e838e9cd307f6c6a0d620b5e07e6f927b07d05f6d12a1ac8d7',
+            headers=get_manifest_authorization_header('username', 'password'),
+            params=None,
+            json=None,
+            timeout=300,
+            verify=mock.ANY)
 
     @mock.patch('azure.cli.command_modules.acr.manifest.get_access_credentials', autospec=True)
     @mock.patch('azure.cli.command_modules.acr.repository.get_access_credentials', autospec=True)
