@@ -42,6 +42,10 @@ CONST_DEFAULT_NODE_VM_SIZE = "Standard_DS2_v2"
 CONST_DEFAULT_WINDOWS_NODE_VM_SIZE = "Standard_D2s_v3"
 
 # consts for ManagedCluster
+# load balancer sku
+CONST_LOAD_BALANCER_SKU_BASIC = "basic"
+CONST_LOAD_BALANCER_SKU_STANDARD = "standard"
+
 # outbound type
 CONST_OUTBOUND_TYPE_LOAD_BALANCER = "loadBalancer"
 CONST_OUTBOUND_TYPE_USER_DEFINED_ROUTING = "userDefinedRouting"
@@ -52,10 +56,13 @@ CONST_OUTBOUND_TYPE_USER_ASSIGNED_NAT_GATEWAY = "userAssignedNATGateway"
 CONST_PRIVATE_DNS_ZONE_SYSTEM = "system"
 CONST_PRIVATE_DNS_ZONE_NONE = "none"
 
-# used to set identity profile (for kubelet)
+# role assignment for kubelet
 CONST_MANAGED_IDENTITY_OPERATOR_ROLE = 'Managed Identity Operator'
 CONST_MANAGED_IDENTITY_OPERATOR_ROLE_ID = 'f1a07417-d97a-45cb-824c-7a7467783830'
 
+# role assignment for vnet subnet
+CONST_NETWORK_CONTRIBUTOR_ROLE_ID = "4d97b98b-1d4f-4787-a291-c67834d212e7"
+
 # upgrade channel
 CONST_RAPID_UPGRADE_CHANNEL = "rapid"
 CONST_STABLE_UPGRADE_CHANNEL = "stable"
@@ -121,6 +128,7 @@ ADDONS = {
 
 # consts for check-acr command
 CONST_CANIPULL_IMAGE = "mcr.microsoft.com/aks/canipull:0.0.4-alpha"
+CONST_ACR_DOMAIN_NAME = ".azurecr.io"
 
 
 # consts for decorator pattern
