@@ -11,6 +11,7 @@ from azure.cli.command_modules.acs._completers import (
     get_k8s_upgrades_completion_list, get_k8s_versions_completion_list,
     get_vm_size_completion_list)
 from azure.cli.command_modules.acs._consts import (
+    CONST_LOAD_BALANCER_SKU_BASIC, CONST_LOAD_BALANCER_SKU_STANDARD,
     CONST_NETWORK_PLUGIN_AZURE, CONST_NETWORK_PLUGIN_KUBENET,
     CONST_NODE_IMAGE_UPGRADE_CHANNEL, CONST_NODEPOOL_MODE_SYSTEM,
     CONST_NODEPOOL_MODE_USER, CONST_NONE_UPGRADE_CHANNEL,
@@ -39,7 +40,8 @@ from azure.cli.command_modules.acs._validators import (
     validate_nodes_count, validate_pod_subnet_id, validate_ppg,
     validate_priority, validate_snapshot_id, validate_snapshot_name,
     validate_spot_max_price, validate_ssh_key, validate_taints,
-    validate_vm_set_type, validate_vnet_subnet_id)
+    validate_vm_set_type, validate_vnet_subnet_id,
+    validate_defender_disable_and_enable_parameters, validate_defender_config_parameter)
 from azure.cli.core.commands.parameters import (
     edge_zone_type, file_type, get_enum_type,
     get_resource_name_completion_list, get_three_state_flag, name_type,
@@ -91,8 +93,10 @@ node_eviction_policies = [CONST_SPOT_EVICTION_POLICY_DELETE, CONST_SPOT_EVICTION
 node_os_disk_types = [CONST_OS_DISK_TYPE_MANAGED, CONST_OS_DISK_TYPE_EPHEMERAL]
 node_mode_types = [CONST_NODEPOOL_MODE_SYSTEM, CONST_NODEPOOL_MODE_USER]
 node_os_skus = [CONST_OS_SKU_UBUNTU, CONST_OS_SKU_CBLMARINER]
+scale_down_modes = [CONST_SCALE_DOWN_MODE_DELETE, CONST_SCALE_DOWN_MODE_DEALLOCATE]
 
 # consts for ManagedCluster
+load_balancer_skus = [CONST_LOAD_BALANCER_SKU_BASIC, CONST_LOAD_BALANCER_SKU_STANDARD]
 network_plugins = [CONST_NETWORK_PLUGIN_KUBENET, CONST_NETWORK_PLUGIN_AZURE]
 outbound_types = [CONST_OUTBOUND_TYPE_LOAD_BALANCER, CONST_OUTBOUND_TYPE_USER_DEFINED_ROUTING, CONST_OUTBOUND_TYPE_MANAGED_NAT_GATEWAY, CONST_OUTBOUND_TYPE_USER_ASSIGNED_NAT_GATEWAY]
 auto_upgrade_channels = [
@@ -211,33 +215,28 @@ def load_arguments(self, _):
         c.argument('name', validator=validate_linux_host_name)
         c.argument('kubernetes_version',
                    completer=get_k8s_versions_completion_list)
-        c.argument('admin_username', options_list=[
-                   '--admin-username', '-u'], default='azureuser')
-        c.argument('generate_ssh_keys', action='store_true',
-                   validator=validate_create_parameters)
-        c.argument('ssh_key_value', required=False, type=file_type, default=os.path.join('~', '.ssh', 'id_rsa.pub'),
-                   completer=FilesCompleter(), validator=validate_ssh_key)
-        c.argument('no_ssh_key', options_list=['--no-ssh-key', '-x'])
-        c.argument('edge_zone', edge_zone_type)
+        c.argument('dns_name_prefix', options_list=['--dns-name-prefix', '-p'])
         c.argument('node_osdisk_diskencryptionset_id', options_list=['--node-osdisk-diskencryptionset-id', '-d'])
         c.argument('disable_local_accounts', action='store_true')
         c.argument('disable_rbac', action='store_true')
-        c.argument('enable_rbac', action='store_true', options_list=['--enable-rbac', '-r'],
-                   deprecate_info=c.deprecate(redirect="--disable-rbac", hide="2.0.45"))
+        c.argument('edge_zone', edge_zone_type)
+        c.argument('admin_username', options_list=['--admin-username', '-u'], default='azureuser')
+        c.argument('generate_ssh_keys', action='store_true', validator=validate_create_parameters)
+        c.argument('ssh_key_value', required=False, type=file_type, default=os.path.join('~', '.ssh', 'id_rsa.pub'),
+                   completer=FilesCompleter(), validator=validate_ssh_key)
+        c.argument('no_ssh_key', options_list=['--no-ssh-key', '-x'])
         c.argument('dns_service_ip')
         c.argument('docker_bridge_address')
         c.argument('pod_cidr')
         c.argument('service_cidr')
-        c.argument('load_balancer_sku', validator=validate_load_balancer_sku)
+        c.argument('load_balancer_sku', arg_type=get_enum_type(load_balancer_skus), validator=validate_load_balancer_sku)
         c.argument('load_balancer_managed_outbound_ip_count', type=int)
         c.argument('load_balancer_outbound_ips', validator=validate_load_balancer_outbound_ips)
         c.argument('load_balancer_outbound_ip_prefixes', validator=validate_load_balancer_outbound_ip_prefixes)
         c.argument('load_balancer_outbound_ports', type=int, validator=validate_load_balancer_outbound_ports)
         c.argument('load_balancer_idle_timeout', type=int, validator=validate_load_balancer_idle_timeout)
-        c.argument('nat_gateway_managed_outbound_ip_count', type=int,
-                   validator=validate_nat_gateway_managed_outbound_ip_count)
-        c.argument('nat_gateway_idle_timeout', type=int,
-                   validator=validate_nat_gateway_idle_timeout)
+        c.argument('nat_gateway_managed_outbound_ip_count', type=int, validator=validate_nat_gateway_managed_outbound_ip_count)
+        c.argument('nat_gateway_idle_timeout', type=int, validator=validate_nat_gateway_idle_timeout)
         c.argument('outbound_type', arg_type=get_enum_type(outbound_types))
         c.argument('network_plugin', arg_type=get_enum_type(network_plugins))
         c.argument('network_policy')
@@ -245,7 +244,6 @@ def load_arguments(self, _):
         c.argument('cluster_autoscaler_profile', nargs='+', options_list=["--cluster-autoscaler-profile", "--ca-profile"],
                    help="Space-separated list of key=value pairs for configuring cluster autoscaler. Pass an empty string to clear the profile.")
         c.argument('uptime_sla', action='store_true')
-        c.argument('dns_name_prefix', options_list=['--dns-name-prefix', '-p'])
         c.argument('fqdn_subdomain')
         c.argument('api_server_authorized_ip_ranges', validator=validate_ip_ranges)
         c.argument('enable_private_cluster', action='store_true')
@@ -271,6 +269,9 @@ def load_arguments(self, _):
         c.argument('gmsa_root_domain_name')
         c.argument('attach_acr', acr_arg_type)
         c.argument('skip_subnet_role_assignment', action='store_true')
+        c.argument('node_resource_group')
+        c.argument('enable_defender', action='store_true')
+        c.argument('defender_config', validator=validate_defender_config_parameter)
         # addons
         c.argument('enable_addons', options_list=['--enable-addons', '-a'])
         c.argument('workspace_resource_id')
@@ -289,6 +290,7 @@ def load_arguments(self, _):
                    help='Node pool name, up to 12 alphanumeric characters', validator=validate_nodepool_name)
         c.argument('node_vm_size', options_list=['--node-vm-size', '-s'], completer=get_vm_size_completion_list)
         c.argument('os_sku', arg_type=get_enum_type(node_os_skus))
+        c.argument('snapshot_id', validator=validate_snapshot_id)
         c.argument('vnet_subnet_id', validator=validate_vnet_subnet_id)
         c.argument('pod_subnet_id', validator=validate_pod_subnet_id)
         c.argument('enable_node_public_ip', action='store_true')
@@ -309,11 +311,9 @@ def load_arguments(self, _):
         c.argument('enable_encryption_at_host', action='store_true')
         c.argument('enable_ultra_ssd', action='store_true')
         c.argument('enable_fips_image', action='store_true')
-        c.argument('snapshot_id', validator=validate_snapshot_id)
         c.argument('kubelet_config')
         c.argument('linux_os_config')
-        c.argument('yes', options_list=[
-                   '--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
+        c.argument('yes', options_list=['--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
 
     with self.argument_context('aks update') as c:
         # managed cluster paramerters
@@ -336,6 +336,7 @@ def load_arguments(self, _):
         c.argument('disable_public_fqdn', action='store_true')
         c.argument('enable_managed_identity', action='store_true')
         c.argument('assign_identity', validator=validate_assign_identity)
+        c.argument('assign_kubelet_identity', validator=validate_assign_kubelet_identity)
         c.argument('enable_aad', action='store_true')
         c.argument('enable_azure_rbac', action='store_true')
         c.argument('disable_azure_rbac', action='store_true')
@@ -349,6 +350,9 @@ def load_arguments(self, _):
         c.argument('gmsa_root_domain_name')
         c.argument('attach_acr', acr_arg_type, validator=validate_acr)
         c.argument('detach_acr', acr_arg_type, validator=validate_acr)
+        c.argument('disable_defender', action='store_true', validator=validate_defender_disable_and_enable_parameters)
+        c.argument('enable_defender', action='store_true')
+        c.argument('defender_config', validator=validate_defender_config_parameter)
         # addons
         c.argument('enable_secret_rotation', action='store_true')
         c.argument('disable_secret_rotation', action='store_true')
@@ -364,8 +368,7 @@ def load_arguments(self, _):
         c.argument('max_count', type=int, validator=validate_nodes_count)
         c.argument('nodepool_labels', nargs='*', validator=validate_nodepool_labels,
                    help='space-separated labels: key[=value] [key[=value] ...]. See https://aka.ms/node-labels for syntax of labels.')
-        c.argument('yes', options_list=[
-                   '--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
+        c.argument('yes', options_list=['--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
 
     with self.argument_context('aks disable-addons', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='managed_clusters') as c:
         c.argument('addons', options_list=['--addons', '-a'])
@@ -420,14 +423,16 @@ def load_arguments(self, _):
         c.argument('aad_tenant_id')
 
     with self.argument_context('aks upgrade', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='managed_clusters') as c:
-        c.argument('kubernetes_version',
-                   completer=get_k8s_upgrades_completion_list)
-        c.argument('yes', options_list=[
-                   '--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
+        c.argument('kubernetes_version', completer=get_k8s_upgrades_completion_list)
+        c.argument('yes', options_list=['--yes', '-y'], help='Do not prompt for confirmation.', action='store_true')
 
     with self.argument_context('aks scale', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='managed_clusters') as c:
         c.argument('nodepool_name', validator=validate_nodepool_name, help='Node pool name, up to 12 alphanumeric characters.')
 
+    with self.argument_context('aks check-acr', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='managed_clusters') as c:
+        c.argument('acr')
+        c.argument('node_name')
+
     with self.argument_context('aks nodepool', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='managed_clusters') as c:
         c.argument('cluster_name', help='The cluster name.')
         # the following argument is declared for the wait command
@@ -441,6 +446,7 @@ def load_arguments(self, _):
         c.argument('node_vm_size', options_list=['--node-vm-size', '-s'], completer=get_vm_size_completion_list)
         c.argument('os_type')
         c.argument('os_sku', arg_type=get_enum_type(node_os_skus))
+        c.argument('snapshot_id', validator=validate_snapshot_id)
         c.argument('vnet_subnet_id', validator=validate_vnet_subnet_id)
         c.argument('pod_subnet_id', validator=validate_pod_subnet_id)
         c.argument('enable_node_public_ip', action='store_true')
@@ -456,16 +462,15 @@ def load_arguments(self, _):
         c.argument('node_taints', validator=validate_taints)
         c.argument('node_osdisk_type', arg_type=get_enum_type(node_os_disk_types))
         c.argument('node_osdisk_size', type=int)
-        c.argument('mode', get_enum_type(node_mode_types))
-        c.argument('scale_down_mode', arg_type=get_enum_type([CONST_SCALE_DOWN_MODE_DELETE, CONST_SCALE_DOWN_MODE_DEALLOCATE]))
         c.argument('max_surge', validator=validate_max_surge)
+        c.argument('mode', get_enum_type(node_mode_types))
+        c.argument('scale_down_mode', arg_type=get_enum_type(scale_down_modes))
         c.argument('max_pods', type=int, options_list=['--max-pods', '-m'])
         c.argument('zones', zones_type, options_list=['--zones', '-z'], help='Space-separated list of availability zones where agent nodes will be placed.')
         c.argument('ppg', validator=validate_ppg)
         c.argument('enable_encryption_at_host', action='store_true')
         c.argument('enable_ultra_ssd', action='store_true')
         c.argument('enable_fips_image', action='store_true')
-        c.argument('snapshot_id', validator=validate_snapshot_id)
         c.argument('kubelet_config')
         c.argument('linux_os_config')
 
@@ -481,9 +486,9 @@ def load_arguments(self, _):
         c.argument('labels', nargs='*', validator=validate_nodepool_labels)
         c.argument('tags', tags_type)
         c.argument('node_taints', validator=validate_taints)
-        c.argument('mode', get_enum_type(node_mode_types))
-        c.argument('scale_down_mode', arg_type=get_enum_type([CONST_SCALE_DOWN_MODE_DELETE, CONST_SCALE_DOWN_MODE_DEALLOCATE]))
         c.argument('max_surge', validator=validate_max_surge)
+        c.argument('mode', get_enum_type(node_mode_types))
+        c.argument('scale_down_mode', arg_type=get_enum_type(scale_down_modes))
 
     with self.argument_context('aks nodepool upgrade') as c:
         c.argument('snapshot_id', validator=validate_snapshot_id)
@@ -509,27 +514,6 @@ def load_arguments(self, _):
         c.argument('prompt', options_list=[
                    '--yes', '-y'], action='store_true', help='Do not prompt for confirmation')
 
-    # OpenShift command argument configuration
-    with self.argument_context('openshift', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='open_shift_managed_clusters') as c:
-        c.argument('resource_name', name_type, help='Name of the managed OpenShift cluster.',
-                   completer=get_resource_name_completion_list('Microsoft.ContainerService/OpenShiftManagedClusters'))
-        c.argument('name', name_type, help='Name of the managed OpenShift cluster.',
-                   completer=get_resource_name_completion_list('Microsoft.ContainerService/OpenShiftManagedClusters'))
-        c.argument('compute_count', options_list=[
-                   '--compute-count', '-c'], type=int, default=4)
-        c.argument('tags', tags_type)
-
-    with self.argument_context('openshift create', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='open_shift_managed_clusters') as c:
-        c.argument('name', validator=validate_linux_host_name)
-        c.argument('compute_vm_size', options_list=['--compute-vm-size', '-s'])
-        c.argument('customer_admin_group_id', options_list=[
-                   '--customer-admin-group-id'])
-        c.argument('workspace_id')
-
-    with self.argument_context('openshift monitor enable', resource_type=ResourceType.MGMT_CONTAINERSERVICE, operation_group='open_shift_managed_clusters') as c:
-        c.argument(
-            'workspace_id', help='The resource ID of an existing Log Analytics Workspace to use for storing monitoring data.')
-
     for scope in ['aks nodepool snapshot create', 'aks snapshot create']:
         with self.argument_context(scope) as c:
             c.argument('snapshot_name', options_list=['--name', '-n'], required=True, validator=validate_snapshot_name, help='The nodepool snapshot name.')
