@@ -5,39 +5,8 @@
 import unittest
 
 from azure.cli.command_modules.acs import _validators as validators
-from azure.cli.core._config import ENV_VAR_PREFIX, GLOBAL_CONFIG_DIR
 from azure.cli.core.azclierror import InvalidArgumentValueError
-from azure.cli.core.cloud import get_active_cloud
-from azure.cli.core.profiles import ResourceType, get_sdk
 from azure.cli.core.util import CLIError
-from knack import CLI
-
-class MockCLI(CLI):
-    def __init__(self):
-        super(MockCLI, self).__init__(cli_name='mock_cli', config_dir=GLOBAL_CONFIG_DIR,
-                                      config_env_var_prefix=ENV_VAR_PREFIX, commands_loader_cls=MockLoader)
-        self.cloud = get_active_cloud(self)
-
-
-class MockLoader(object):
-    def __init__(self, ctx):
-        self.ctx = ctx
-
-    def get_models(self, *attr_args, **_):
-        from azure.cli.core.profiles import get_sdk
-        return get_sdk(self.ctx, ResourceType.MGMT_CONTAINERSERVICE, 'ManagedClusterPropertiesAutoScalerProfile',
-                       mod='models', operation_group='managed_clusters')
-
-
-class MockCmd(object):
-    def __init__(self, ctx, arguments={}):
-        self.cli_ctx = ctx
-        self.loader = MockLoader(self.cli_ctx)
-        self.arguments = arguments
-
-    def get_models(self, *attr_args, **kwargs):
-        return get_sdk(self.cli_ctx, ResourceType.MGMT_CONTAINERSERVICE, 'ManagedClusterPropertiesAutoScalerProfile',
-                       mod='models', operation_group='managed_clusters')
 
 
 class TestValidateIPRanges(unittest.TestCase):
@@ -95,9 +64,10 @@ class TestValidateIPRanges(unittest.TestCase):
 
 
 class Namespace:
-    def __init__(self, api_server_authorized_ip_ranges=None, cluster_autoscaler_profile=None):
+    def __init__(self, api_server_authorized_ip_ranges=None, cluster_autoscaler_profile=None, kubernetes_version=None):
         self.api_server_authorized_ip_ranges = api_server_authorized_ip_ranges
         self.cluster_autoscaler_profile = cluster_autoscaler_profile
+        self.kubernetes_version = kubernetes_version
 
 
 class TestVNetSubnetId(unittest.TestCase):
@@ -130,6 +100,7 @@ class VnetSubnetIdNamespace:
     def __init__(self, vnet_subnet_id):
         self.vnet_subnet_id = vnet_subnet_id
 
+
 class TestPodSubnetId(unittest.TestCase):
     def test_invalid_pod_subnet_id(self):
         invalid_pod_subnet_id = "dummy subnet id"
@@ -420,5 +391,46 @@ class TestCredentialFormat(unittest.TestCase):
         validators.validate_credential_format(namespace)
 
 
+class TestValidateKubernetesVersion(unittest.TestCase):
+    def test_valid_full_kubernetes_version(self):
+        kubernetes_version = "1.11.8"
+        namespace = Namespace(kubernetes_version=kubernetes_version)
+
+        validators.validate_k8s_version(namespace)
+
+    def test_valid_alias_minor_version(self):
+        kubernetes_version = "1.11"
+        namespace = Namespace(kubernetes_version=kubernetes_version)
+
+        validators.validate_k8s_version(namespace)
+
+    def test_valid_empty_kubernetes_version(self):
+        kubernetes_version = ""
+        namespace = Namespace(kubernetes_version=kubernetes_version)
+
+        validators.validate_k8s_version(namespace)
+
+    def test_invalid_kubernetes_version(self):
+        kubernetes_version = "1.2.3.4"
+
+        namespace = Namespace(kubernetes_version=kubernetes_version)
+        err = (
+            "--kubernetes-version should be the full version number or major.minor version number, "
+            'such as "1.7.12" or "1.7"'
+        )
+
+        with self.assertRaises(CLIError) as cm:
+            validators.validate_k8s_version(namespace)
+        self.assertEqual(str(cm.exception), err)
+
+        kubernetes_version = "1."
+
+        namespace = Namespace(kubernetes_version=kubernetes_version)
+
+        with self.assertRaises(CLIError) as cm:
+            validators.validate_k8s_version(namespace)
+        self.assertEqual(str(cm.exception), err)
+
+
 if __name__ == "__main__":
     unittest.main()
