@@ -483,6 +483,11 @@ def load_command_table(self, _):
         g.custom_command('unlink', 'unlink_user_function', validator=validate_staticsite_sku)
         g.custom_show_command('show', 'get_user_function', validator=validate_staticsite_sku)
 
+    with self.command_group('staticwebapp enterprise-edge', custom_command_type=staticsite_sdk) as g:
+        g.custom_command('enable', 'enable_staticwebapp_enterprise_edge')
+        g.custom_command('disable', 'disable_staticwebapp_enterprise_edge')
+        g.custom_show_command('show', 'show_staticwebapp_enterprise_edge_status')
+
     with self.command_group('logicapp') as g:
         g.custom_command('delete', 'delete_function_app', confirmation=True)
         g.custom_command('stop', 'stop_webapp')
