@@ -341,6 +341,22 @@ def cli_networkrule_createupdate(cmd, client, resource_group_name, namespace_nam
     return client.create_or_update_network_rule_set(resource_group_name, namespace_name, netwrokruleset)
 
 
+def cli_networkrule_update(client, resource_group_name, namespace_name, public_network_access=None, trusted_service_access_enabled=None,
+                           default_action=None):
+    networkruleset = client.get_network_rule_set(resource_group_name, namespace_name)
+
+    if trusted_service_access_enabled is not None:
+        networkruleset.trusted_service_access_enabled = trusted_service_access_enabled
+
+    if public_network_access:
+        networkruleset.public_network_access = public_network_access
+
+    if default_action:
+        networkruleset.default_action = default_action
+
+    return client.create_or_update_network_rule_set(resource_group_name, namespace_name, networkruleset)
+
+
 def cli_networkrule_delete(cmd, client, resource_group_name, namespace_name, subnet=None, ip_mask=None):
     NWRuleSetVirtualNetworkRules = cmd.get_models('NWRuleSetVirtualNetworkRules', resource_type=ResourceType.MGMT_EVENTHUB)
     NWRuleSetIpRules = cmd.get_models('NWRuleSetIpRules', resource_type=ResourceType.MGMT_EVENTHUB)
@@ -561,3 +577,52 @@ def cli_remove_encryption(client, resource_group_name, namespace_name, encryptio
     get_namespace = client.get(resource_group_name, namespace_name)
 
     return get_namespace
+
+
+def cli_schemaregistry_createupdate(cmd, client, resource_group_name, namespace_name, schema_group_name,
+                                    schema_compatibility, schema_type, tags=None):
+    SchemaGroup = cmd.get_models('SchemaGroup', resource_type=ResourceType.MGMT_EVENTHUB)
+    ehSchemaGroup = SchemaGroup(schema_compatibility=schema_compatibility, schema_type=schema_type, group_properties=tags)
+
+    return client.create_or_update(resource_group_name, namespace_name, schema_group_name, ehSchemaGroup)
+
+
+def cli_appgroup_create(cmd, client, resource_group_name, namespace_name, application_group_name, client_app_group_identifier,
+                        throttling_policy_config, is_enabled=None):
+    ApplicationGroup = cmd.get_models('ApplicationGroup', resource_type=ResourceType.MGMT_EVENTHUB)
+    appGroup = ApplicationGroup(policies=throttling_policy_config, client_app_group_identifier=client_app_group_identifier)
+
+    if is_enabled is not None:
+        ApplicationGroup.is_enabled = is_enabled
+
+    return client.create_or_update_application_group(resource_group_name, namespace_name, application_group_name, appGroup)
+
+
+def cli_appgroup_update(client, resource_group_name, namespace_name, application_group_name, is_enabled=None):
+    appGroup = client.get(resource_group_name, namespace_name, application_group_name)
+
+    if is_enabled is not None:
+        appGroup.is_enabled = is_enabled
+
+    return client.create_or_update_application_group(resource_group_name, namespace_name, application_group_name, appGroup)
+
+
+def cli_add_appgroup_policy(client, resource_group_name, namespace_name, application_group_name, throttling_policy_config):
+    appGroup = client.get(resource_group_name, namespace_name, application_group_name)
+    appGroup.policies.extend(throttling_policy_config)
+    return client.create_or_update_application_group(resource_group_name, namespace_name, application_group_name, appGroup)
+
+
+def cli_remove_appgroup_policy(client, resource_group_name, namespace_name, application_group_name, throttling_policy_config):
+    from azure.cli.core import CLIError
+
+    appGroup = client.get(resource_group_name, namespace_name, application_group_name)
+
+    if appGroup.policies:
+        for policy_object in throttling_policy_config:
+            if policy_object in appGroup.policies:
+                appGroup.policies.remove(policy_object)
+            else:
+                raise CLIError('The following policy was not found: Name: ' + policy_object.name + ', RateLimitThreshold: ' + str(policy_object.rate_limit_threshold) + ', MetricId: ' + policy_object.metric_id)
+
+    return client.create_or_update_application_group(resource_group_name, namespace_name, application_group_name, appGroup)
