@@ -377,149 +377,6 @@ type: command
 short-summary: List the event categories of activity logs.
 """
 
-helps['monitor alert'] = """
-type: group
-short-summary: Manage classic metric-based alert rules.
-"""
-
-helps['monitor alert create'] = """
-type: command
-short-summary: Create a classic metric-based alert rule.
-parameters:
-  - name: --action -a
-    short-summary: Add an action to fire when the alert is triggered.
-    long-summary: |
-        Usage:   --action TYPE KEY [ARG ...]
-        Email:   --action email bob@contoso.com ann@contoso.com
-        Webhook: --action webhook https://www.contoso.com/alert apiKey=value
-        Webhook: --action webhook https://www.contoso.com/alert?apiKey=value
-        Multiple actions can be specified by using more than one `--action` argument.
-  - name: --description
-    short-summary: Free-text description of the rule. Defaults to the condition expression.
-  - name: --disabled
-    short-summary: Create the rule in a disabled state.
-  - name: --condition
-    short-summary: The condition which triggers the rule.
-    long-summary: >
-        The form of a condition is "METRIC {>,>=,<,<=} THRESHOLD {avg,min,max,total,last} PERIOD".
-        Values for METRIC and appropriate THRESHOLD values can be obtained from `az monitor metric` commands,
-        and PERIOD is of the form "##h##m##s".
-  - name: --email-service-owners
-    short-summary: Email the service owners if an alert is triggered.
-examples:
-  - name: Create a high CPU usage alert on a VM with no actions.
-    text: >
-        az monitor alert create -n rule1 -g {ResourceGroup} --target {VirtualMachineID} --condition "Percentage CPU > 90 avg 5m"
-  - name: Create a high CPU usage alert on a VM with email and webhook actions.
-    text: |
-        az monitor alert create -n rule1 -g {ResourceGroup} --target {VirtualMachineID} \\
-            --condition "Percentage CPU > 90 avg 5m" \\
-            --action email bob@contoso.com ann@contoso.com --email-service-owners \\
-            --action webhook https://www.contoso.com/alerts?type=HighCPU \\
-            --action webhook https://alerts.contoso.com apiKey={APIKey} type=HighCPU
-"""
-
-helps['monitor alert delete'] = """
-type: command
-short-summary: Delete an alert rule.
-examples:
-  - name: Delete an alert rule. (autogenerated)
-    text: |
-        az monitor alert delete --name MyAlertRule --resource-group MyResourceGroup
-    crafted: true
-"""
-
-helps['monitor alert list'] = """
-type: command
-short-summary: List alert rules in a resource group.
-examples:
-  - name: List alert rules in a resource group. (autogenerated)
-    text: |
-        az monitor alert list --resource-group MyResourceGroup
-    crafted: true
-"""
-
-helps['monitor alert list-incidents'] = """
-type: command
-short-summary: List all incidents for an alert rule.
-examples:
-  - name: List all incidents for an alert rule. (autogenerated)
-    text: |
-        az monitor alert list-incidents --resource-group MyResourceGroup --rule-name MyRule
-    crafted: true
-"""
-
-helps['monitor alert show'] = """
-type: command
-short-summary: Show an alert rule.
-examples:
-  - name: Show an alert rule. (autogenerated)
-    text: |
-        az monitor alert show --name MyAlertRule --resource-group MyResourceGroup
-    crafted: true
-"""
-
-helps['monitor alert show-incident'] = """
-type: command
-short-summary: Get the details of an alert rule incident.
-"""
-
-helps['monitor alert update'] = """
-type: command
-short-summary: Update a classic metric-based alert rule.
-parameters:
-  - name: --description
-    short-summary: Description of the rule.
-  - name: --condition
-    short-summary: The condition which triggers the rule.
-    long-summary: >
-        The form of a condition is "METRIC {>,>=,<,<=} THRESHOLD {avg,min,max,total,last} PERIOD".
-        Values for METRIC and appropriate THRESHOLD values can be obtained from `az monitor metric` commands,
-        and PERIOD is of the form "##h##m##s".
-  - name: --add-action -a
-    short-summary: Add an action to fire when the alert is triggered.
-    long-summary: |
-        Usage:   --add-action TYPE KEY [ARG ...]
-        Email:   --add-action email bob@contoso.com ann@contoso.com
-        Webhook: --add-action webhook https://www.contoso.com/alert apiKey=value
-        Webhook: --add-action webhook https://www.contoso.com/alert?apiKey=value
-        Multiple actions can be specified by using more than one `--add-action` argument.
-  - name: --remove-action -r
-    short-summary: Remove one or more actions.
-    long-summary: |
-        Usage:   --remove-action TYPE KEY [KEY ...]
-        Email:   --remove-action email bob@contoso.com ann@contoso.com
-        Webhook: --remove-action webhook https://contoso.com/alert https://alerts.contoso.com
-  - name: --email-service-owners
-    short-summary: Email the service owners if an alert is triggered.
-  - name: --metric
-    short-summary: Name of the metric to base the rule on.
-    populator-commands:
-      - az monitor metrics list-definitions
-  - name: --operator
-    short-summary: How to compare the metric against the threshold.
-  - name: --threshold
-    short-summary: Numeric threshold at which to trigger the alert.
-  - name: --aggregation
-    short-summary: Type of aggregation to apply based on --period.
-  - name: --period
-    short-summary: >
-        Time span over which to apply --aggregation, in nDnHnMnS shorthand or full ISO8601 format.
-examples:
-  - name: Update a classic metric-based alert rule. (autogenerated)
-    text: |
-        az monitor alert update --email-service-owners true --name MyAlertRule --resource-group MyResourceGroup
-    crafted: true
-  - name: Update a classic metric-based alert rule. (autogenerated)
-    text: |
-        az monitor alert update --name MyAlertRule --remove-action email bob@contoso.com --resource-group MyResourceGroup
-    crafted: true
-  - name: Update a classic metric-based alert rule. (autogenerated)
-    text: |
-        az monitor alert update --name MyAlertRule --resource-group MyResourceGroup --set retentionPolicy.days=365
-    crafted: true
-"""
-
 helps['monitor autoscale'] = """
 type: group
 short-summary: Manage autoscale settings.
@@ -783,21 +640,6 @@ examples:
     crafted: true
 """
 
-helps['monitor autoscale-settings'] = """
-type: group
-short-summary: Manage autoscale settings.
-"""
-
-helps['monitor autoscale-settings update'] = """
-type: command
-short-summary: Updates an autoscale setting.
-examples:
-  - name: Updates an autoscale setting. (autogenerated)
-    text: |
-        az monitor autoscale-settings update --name MyAutoscaleSetting --resource-group MyResourceGroup --set retentionPolicy.days=365
-    crafted: true
-"""
-
 helps['monitor diagnostic-settings'] = """
 type: group
 short-summary: Manage service diagnostic settings.
@@ -950,43 +792,6 @@ examples:
     text: az monitor log-analytics cluster create -g MyResourceGroup -n MyCluster --sku-capacity 1000
 """
 
-helps['monitor log-analytics cluster update'] = """
-type: command
-short-summary: Update a cluster instance.
-examples:
-  - name: Update a cluster instance.
-    text: |
-        az monitor log-analytics cluster update -g MyResourceGroup -n MyCluster \\
-          --key-vault-uri https://myvault.vault.azure.net/ --key-name my-key \\
-          --key-version fe0adcedd8014aed9c22e9aefb81a1ds --sku-capacity 1000
-"""
-
-helps['monitor log-analytics cluster delete'] = """
-type: command
-short-summary: Delete a cluster instance.
-examples:
-  - name: Delete a cluster instance.
-    text: az monitor log-analytics cluster delete -g MyResourceGroup -n MyCluster
-"""
-
-helps['monitor log-analytics cluster show'] = """
-type: command
-short-summary: Show the properties of a cluster instance.
-examples:
-  - name: Show the properties of a cluster instance.
-    text: az monitor log-analytics cluster show -g MyResourceGroup -n MyCluster
-"""
-
-helps['monitor log-analytics cluster list'] = """
-type: command
-short-summary: Gets all cluster instances in a resource group or in current subscription.
-examples:
-  - name: Gets all cluster instances in a resource group.
-    text: az monitor log-analytics cluster list -g MyResourceGroup
-  - name: Gets all cluster instances in current subscription.
-    text: az monitor log-analytics cluster list
-"""
-
 helps['monitor log-analytics cluster wait'] = """
 type: command
 short-summary: Place the CLI in a waiting state until a condition of the cluster is met.
