@@ -106,31 +106,36 @@ def load_command_table(self, _):
 def load_accounts_command_groups(self, netappfiles_accounts_sdk):
     with self.command_group('netappfiles account', netappfiles_accounts_sdk) as g:
         g.show_command('show', 'get')
-        g.command('delete', 'begin_delete')
+        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.custom_command('list', 'list_accounts',
                          client_factory=accounts_mgmt_client_factory,
-                         doc_string_source='azure.mgmt.netapp.models#NetAppAccount',
+                         doc_string_source='azure.mgmt.netapp.models#NetAppAccountList',
                          exception_handler=netappfiles_exception_handler)
         g.custom_command('create', 'create_account',
                          client_factory=accounts_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#NetAppAccount',
                          exception_handler=netappfiles_exception_handler)
         g.generic_update_command('update',
                                  setter_name='begin_update',
+                                 supports_no_wait=True,
                                  custom_func_name='patch_account',
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#NetAppAccountPatch',
                                  exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
     with self.command_group('netappfiles account ad', netappfiles_accounts_sdk) as g:
         g.generic_update_command('add',
                                  setter_name='begin_update',
+                                 supports_no_wait=True,
                                  custom_func_name='add_active_directory',
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#NetAppAccountPatch',
                                  exception_handler=netappfiles_exception_handler)
         g.generic_update_command('update',
                                  setter_name='begin_update',
+                                 supports_no_wait=True,
                                  custom_func_name='update_active_directory',
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#NetAppAccountPatch',
@@ -141,77 +146,98 @@ def load_accounts_command_groups(self, netappfiles_accounts_sdk):
                          exception_handler=netappfiles_exception_handler)
         g.custom_command('remove', 'remove_active_directory',
                          client_factory=accounts_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#NetAppAccount',
                          exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
 
 def load_account_backup_command_groups(self, netappfiles_account_backups_sdk):
     with self.command_group('netappfiles account backup', netappfiles_account_backups_sdk, is_preview=True) as g:
         g.show_command('show', 'get')
         g.command('list', 'list')
-        g.command('delete', 'begin_delete', confirmation=True)
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
+        g.wait_command('wait')
 
 
 def load_backup_policies_command_groups(self, netappfiles_backup_policies_sdk):
     with self.command_group('netappfiles account backup-policy', netappfiles_backup_policies_sdk) as g:
         g.show_command('show', 'get')
         g.command('list', 'list')
-        g.command('delete', 'begin_delete')
-        g.custom_command('update', 'patch_backup_policy',
-                         client_factory=backup_policies_mgmt_client_factory,
-                         doc_string_source='azure.mgmt.netapp.models#BackupPolicyPatch',
-                         exception_handler=netappfiles_exception_handler)
+        g.command('delete', 'begin_delete', supports_no_wait=True)
+        g.generic_update_command('update',
+                                 setter_name='begin_update',
+                                 custom_func_name='patch_backup_policy',
+                                 supports_no_wait=True,
+                                 setter_arg_name='body',
+                                 doc_string_source='azure.mgmt.netapp.models#BackupPolicyPatch',
+                                 exception_handler=netappfiles_exception_handler)
         g.custom_command('create', 'create_backup_policy',
                          client_factory=backup_policies_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#BackupPolicy',
                          exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
 
 def load_pools_command_groups(self, netappfiles_pools_sdk):
     with self.command_group('netappfiles pool', netappfiles_pools_sdk) as g:
         g.show_command('show', 'get')
         g.command('list', 'list')
-        g.command('delete', 'begin_delete')
+        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.custom_command('create', 'create_pool',
                          client_factory=pools_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#CapacityPool',
                          exception_handler=netappfiles_exception_handler)
         g.generic_update_command('update',
                                  setter_name='begin_update',
                                  custom_func_name='patch_pool',
+                                 supports_no_wait=True,
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#CapacityPoolPatch',
                                  exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
 
 def load_volumes_command_groups(self, netappfiles_volumes_sdk):
     with self.command_group('netappfiles volume', netappfiles_volumes_sdk) as g:
         g.show_command('show', 'get')
         g.command('list', 'list')
-        g.command('delete', 'begin_delete')
+        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.custom_command('create', 'create_volume',
                          client_factory=volumes_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Volume',
                          exception_handler=netappfiles_exception_handler)
         g.generic_update_command('update',
                                  setter_name='begin_update',
                                  custom_func_name='patch_volume',
+                                 supports_no_wait=True,
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#VolumePatch',
                                  exception_handler=netappfiles_exception_handler)
         g.custom_command('revert', 'volume_revert',
                          client_factory=volumes_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Volume',
                          exception_handler=netappfiles_exception_handler)
         g.custom_command('pool-change', 'pool_change',
                          client_factory=volumes_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Volume',
                          exception_handler=netappfiles_exception_handler)
+        g.command('reset-cifs-pw', 'begin_reset_cifs_password', supports_no_wait=True)
+        g.command('relocate', 'begin_relocate', supports_no_wait=True)
+        g.command('finalize-relocation', 'begin_finalize_relocation', supports_no_wait=True)
+        g.command('revert-relocation', 'begin_revert_relocation', supports_no_wait=True, confirmation=True)
+        g.wait_command('wait')
 
     with self.command_group('netappfiles volume export-policy', netappfiles_volumes_sdk) as g:
         g.generic_update_command('add',
                                  setter_name='begin_update',
                                  custom_func_name='add_export_policy_rule',
+                                 supports_no_wait=True,
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#VolumePatch',
                                  exception_handler=netappfiles_exception_handler)
@@ -220,58 +246,72 @@ def load_volumes_command_groups(self, netappfiles_volumes_sdk):
                          doc_string_source='azure.mgmt.netapp.models#Volume',
                          exception_handler=netappfiles_exception_handler)
         g.generic_update_command('remove',
+                                 supports_no_wait=True,
                                  setter_name='begin_update',
                                  custom_func_name='remove_export_policy_rule',
                                  setter_arg_name='body',
                                  doc_string_source='azure.mgmt.netapp.models#VolumePatch',
                                  exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
     with self.command_group('netappfiles volume replication', netappfiles_volumes_sdk) as g:
         g.custom_command('approve', 'authorize_replication',
                          client_factory=volumes_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Volume',
                          exception_handler=netappfiles_exception_handler)
         g.custom_command('suspend', 'break_replication',
                          client_factory=volumes_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Volume',
                          exception_handler=netappfiles_exception_handler)
-        g.command('resume', 'begin_resync_replication')
-        g.command('remove', 'begin_delete_replication')
+        g.command('resume', 'begin_resync_replication', supports_no_wait=True)
+        g.command('remove', 'begin_delete_replication', supports_no_wait=True)
         g.command('status', 'replication_status')
-        g.command('re-initialize', 'begin_re_initialize_replication')
+        g.command('re-initialize', 'begin_re_initialize_replication', supports_no_wait=True)
+        g.command('list', 'list_replications')
+        g.wait_command('wait')
 
 
 def load_backups_command_groups(self, netappfiles_backups_sdk):
     with self.command_group('netappfiles volume backup', netappfiles_backups_sdk, is_preview=True) as g:
         g.show_command('show', 'get')
         g.command('list', 'list')
-        g.command('delete', 'begin_delete')
+        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.command('status', 'get_status')
         g.command('restore-status', 'get_volume_restore_status')
-        g.custom_command('update', 'update_backup',
-                         client_factory=backups_mgmt_client_factory,
-                         doc_string_source='azure.mgmt.netapp.models#BackupPatch',
-                         exception_handler=netappfiles_exception_handler)
+        g.generic_update_command('update',
+                                 supports_no_wait=True,
+                                 setter_name='begin_update',
+                                 custom_func_name='update_backup',
+                                 setter_arg_name='body',
+                                 doc_string_source='azure.mgmt.netapp.models#BackupPatch',
+                                 exception_handler=netappfiles_exception_handler)
         g.custom_command('create', 'create_backup',
                          client_factory=backups_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Backup',
                          exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
 
 def load_snapshots_command_groups(self, netappfiles_snapshots_sdk):
     with self.command_group('netappfiles snapshot', netappfiles_snapshots_sdk) as g:
         g.show_command('show', 'get')
         g.command('list', 'list')
-        g.command('delete', 'begin_delete')
+        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.custom_command('create', 'create_snapshot',
                          client_factory=snapshots_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#Snapshot',
                          exception_handler=netappfiles_exception_handler)
-        g.command('update', 'begin_update')
+        g.command('update', 'begin_update', supports_no_wait=True)
         g.custom_command('restore-files', 'snapshot_restore_files',
                          client_factory=snapshots_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#SnapshotRestoreFiles',
                          exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
 
 def load_snapshots_policies_command_groups(self, netappfiles_snapshot_policies_sdk):
@@ -279,15 +319,17 @@ def load_snapshots_policies_command_groups(self, netappfiles_snapshot_policies_s
         g.show_command('show', 'get')
         g.command('list', 'list')
         g.command('volumes', 'list_volumes')
-        g.command('delete', 'begin_delete')
+        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.custom_command('update', 'patch_snapshot_policy',
                          client_factory=snapshot_policies_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#SnapshotPolicyPatch',
                          exception_handler=netappfiles_exception_handler)
         g.custom_command('create', 'create_snapshot_policy',
                          client_factory=snapshot_policies_mgmt_client_factory,
                          doc_string_source='azure.mgmt.netapp.models#SnapshotPolicy',
                          exception_handler=netappfiles_exception_handler)
+        g.wait_command('wait')
 
 
 def load_vaults_command_groups(self, netappfiles_vaults_sdk):
@@ -301,13 +343,18 @@ def load_subvolumes_command_groups(self, netappfiles_subvolumes_sdk):
         g.command('list', 'list_by_volume')
         g.custom_command('create', 'create_subvolume',
                          client_factory=subvolumes_mgmt_client_factory,
+                         supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#SubvolumeInfo',
                          exception_handler=netappfiles_exception_handler)
-        g.custom_command('update', 'patch_subvolume',
-                         client_factory=subvolumes_mgmt_client_factory,
-                         doc_string_source='azure.mgmt.netapp.models#SubvolumePatchRequest',
-                         exception_handler=netappfiles_exception_handler)
-        g.command('delete', 'begin_delete', confirmation=True)
+        g.generic_update_command('update',
+                                 setter_name='begin_update',
+                                 custom_func_name='patch_subvolume',
+                                 supports_no_wait=True,
+                                 setter_arg_name='body',
+                                 doc_string_source='azure.mgmt.netapp.models#SubvolumePatchRequest',
+                                 exception_handler=netappfiles_exception_handler)
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
+        g.wait_command('wait')
 
     with self.command_group('netappfiles subvolume metadata', netappfiles_subvolumes_sdk) as g:
         g.show_command('show', 'begin_get_metadata')
@@ -322,5 +369,5 @@ def load_volume_groups_command_groups(self, netappfiles_volume_groups_sdk):
                          supports_no_wait=True,
                          doc_string_source='azure.mgmt.netapp.models#VolumeGroupDetails',
                          exception_handler=netappfiles_exception_handler)
-        g.command('delete', 'begin_delete', confirmation=True)
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
         g.wait_command('wait')
