@@ -15,10 +15,8 @@ class NWConnectionMonitorScenarioTest(ScenarioTest):
     def _prepare_vm(self, resource_group, vm):
         vm_create_cmd_tpl = 'vm create -g {rg} --name {vm} ' \
                             '--image UbuntuLTS ' \
-                            '--authentication-type password ' \
-                            '--admin-username deploy ' \
-                            '--admin-password PassPass10!) ' \
                             '--nsg {vm} ' \
+                            '--generate-ssh-keys '\
                             '--nsg-rule None '
         vm_info = self.cmd(vm_create_cmd_tpl.format(rg=resource_group, vm=vm)).get_output_in_json()
 
@@ -352,3 +350,42 @@ class NWConnectionMonitorScenarioTest(ScenarioTest):
         self.cmd('network watcher connection-monitor output list '
                  '--location {location} '
                  '--connection-monitor {cmv2} ')
+
+    @ResourceGroupPreparer(name_prefix='connection_monitor_v2_test_', location='eastus')
+    @AllowLargeResponse()
+    def test_nw_connection_monitor_output_type_as_workspace(self, resource_group, resource_group_location):
+        self.kwargs.update({
+            'rg': resource_group,
+            'location': resource_group_location,
+            'cmv2': 'CMv2-01',
+            'test_group': 'DefaultTestGroup',
+            'workspace_name': self.create_random_name('clitest', 20)
+        })
+
+        vm1_info = self._prepare_vm(resource_group, 'vm1')
+
+        workspace = self.cmd('monitor log-analytics workspace create '
+                             '-g {rg} '
+                             '--location {location} '
+                             '--workspace-name {workspace_name} ').get_output_in_json()
+
+        self.kwargs.update({
+            'vm1_id': vm1_info['id'],
+            'workspace_id': workspace['id']
+        })
+
+        # create a connection monitor v2 with TCP monitoring
+        self.cmd('network watcher connection-monitor create '
+                    '--location {location} '
+                    '--name {cmv2} '
+                    '--endpoint-source-name vm1 '
+                    '--endpoint-source-resource-id {vm1_id} '
+                    '--endpoint-dest-name bing '
+                    '--endpoint-dest-address bing.com '
+                    '--test-config-name DefaultTestConfig '
+                    '--protocol Tcp '
+                    '--tcp-port 2048 '
+                    '--workspace-ids {workspace_id} ', checks=[
+                        self.check('name', '{cmv2}'),
+                        self.check('outputs[0].workspaceSettings.workspaceResourceId', '{workspace_id}')
+                    ])
