@@ -331,7 +331,7 @@ def flexible_server_restart(cmd, client, resource_group_name, server_name, fail_
         client.begin_restart(resource_group_name, server_name, parameters), cmd.cli_ctx, 'PostgreSQL Server Restart')
 
 
-def flexible_server_delete(cmd, client, resource_group_name=None, server_name=None, yes=False):
+def flexible_server_delete(cmd, client, resource_group_name, server_name, yes=False):
     result = None
     if not yes:
         user_confirmation(
@@ -430,7 +430,7 @@ def _create_database(db_context, cmd, resource_group_name, server_name, database
         '{} Database Create/Update'.format(logging_name))
 
 
-def database_create_func(client, resource_group_name=None, server_name=None, database_name=None, charset=None, collation=None):
+def database_create_func(client, resource_group_name, server_name, database_name=None, charset=None, collation=None):
 
     if charset is None and collation is None:
         charset = 'utf8'
