@@ -17,134 +17,56 @@ from knack.util import CLIError
 from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 from azure.cli.core.profiles import ResourceType, get_sdk
 from azure.cli.testsdk import ScenarioTest, LiveScenarioTest, ResourceGroupPreparer, KeyVaultPreparer
+from azure.cli.command_modules.role._msgrpah import GraphError
 from ..util import retry
+from .test_graph import GraphScenarioTestBase
 
 
-class RoleScenarioTest(ScenarioTest):
+class RoleScenarioTestBase(GraphScenarioTestBase):
 
     def run_under_service_principal(self):
-        account_info = self.cmd('account show').get_output_in_json()
-        return account_info['user']['type'] == 'servicePrincipal'
+        return not self._get_signed_in_user()
 
 
-class RbacSPSecretScenarioTest(RoleScenarioTest):
-    def test_create_for_rbac_with_right_display_name(self):
-        sp_name = self.create_random_name('cli-test-sp', 15)
-        self.kwargs['display_name'] = sp_name
-        self.kwargs['display_name_new'] = self.create_random_name('cli-test-sp', 15)
+class CreateForRbacScenarioTest(RoleScenarioTestBase):
 
-        try:
-            sp_info = self.cmd('ad sp create-for-rbac -n {display_name}').get_output_in_json()
-            self.assertTrue(sp_info['displayName'] == sp_name)
-            self.kwargs['app_id'] = sp_info['appId']
+    def test_create_for_rbac_password(self):
+        self.kwargs['display_name'] = self.create_random_name('azure-cli-test-', 30)
+        result = self.cmd('ad sp create-for-rbac --display-name {display_name}',
+                          checks=self.check('displayName', '{display_name}')).get_output_in_json()
+        self.kwargs['app_id'] = result['appId']
+        self.cmd('role assignment list --assignee {app_id} --all', checks=self.check('length(@)', 0))
 
-            # verify password can be used in cli
-            self.kwargs['gen_password'] = sp_info['password']
-            sp_info2 = self.cmd('ad app create --display-name {display_name_new} --password {gen_password}')\
-                .get_output_in_json()
-            self.kwargs['sp_new'] = sp_info2['appId']
-        finally:
-            self.cmd('ad app delete --id {app_id}')
-            self.cmd('ad app delete --id {sp_new}')
+    def test_create_for_rbac_create_cert(self):
 
-    @ResourceGroupPreparer(name_prefix='cli_create_rbac_sp_minimal')
-    def test_create_for_rbac_with_secret_no_assignment(self, resource_group):
+        self.kwargs['display_name'] = self.create_random_name('azure-cli-test-', 30)
 
-        self.kwargs['display_name'] = resource_group
-        try:
-            result = self.cmd('ad sp create-for-rbac -n {display_name}',
+        with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
+            result = self.cmd('ad sp create-for-rbac -n {display_name} --create-cert',
                               checks=self.check('displayName', '{display_name}')).get_output_in_json()
             self.kwargs['app_id'] = result['appId']
-        finally:
-            self.cmd('ad app delete --id {app_id}')
 
-    @AllowLargeResponse()
-    @ResourceGroupPreparer(name_prefix='cli_create_rbac_sp_with_password')
-    def test_create_for_rbac_with_secret_with_assignment(self, resource_group):
+            self.assertTrue(result['fileWithCertAndPrivateKey'].endswith('.pem'))
 
-        subscription_id = self.get_subscription_id()
-        self.kwargs.update({
-            'sub': subscription_id,
-            'scope': f'/subscriptions/{subscription_id}/resourceGroups/{resource_group}',
-            'role': 'Reader',
-            'display_name': resource_group
-        })
+            # On Linux or MacOS, check the cert file is a regular file (S_IFREG 0100000) with permission 600
+            # https://manpages.ubuntu.com/manpages/focal/man7/inode.7.html
+            # Windows doesn't have the Linux permission concept.
+            if sys.platform != 'win32':
+                assert os.stat(result['fileWithCertAndPrivateKey']).st_mode == 0o100600
 
-        try:
-            with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
-                result = self.cmd('ad sp create-for-rbac -n {display_name} '
-                                  '--scopes {scope} --role {role}',
-                                  checks=self.check('displayName', '{display_name}')).get_output_in_json()
-                self.kwargs['app_id'] = result['appId']
-                self.cmd('role assignment list --assignee {app_id} -g {rg}',
-                         checks=[
-                             self.check("length([])", 1),
-                             self.check("[0].roleDefinitionName", '{role}'),
-                             self.check("[0].scope", '{scope}')
-                         ])
-                self.cmd('role assignment delete --assignee {app_id} -g {rg}',
-                         checks=self.is_empty())
-        finally:
-            self.cmd('ad app delete --id {app_id}')
+            os.remove(result['fileWithCertAndPrivateKey'])
 
-    def test_create_for_rbac_argument_error(self):
+            result = self.cmd('ad app credential reset --id {app_id} --create-cert').get_output_in_json()
+            self.assertTrue(result['fileWithCertAndPrivateKey'].endswith('.pem'))
 
-        self.kwargs.update({
-            'scope': '/subscriptions/00000000-0000-0000-0000-000000000000',
-            'role': 'Reader',
-        })
+            if sys.platform != 'win32':
+                assert os.stat(result['fileWithCertAndPrivateKey']).st_mode == 0o100600
 
-        from azure.cli.core.azclierror import ArgumentUsageError
+            os.remove(result['fileWithCertAndPrivateKey'])
 
-        with self.assertRaisesRegex(ArgumentUsageError, 'both'):
-            self.cmd('ad sp create-for-rbac --scopes {scope}')
-
-        with self.assertRaisesRegex(ArgumentUsageError, 'both'):
-            self.cmd('ad sp create-for-rbac --role {role}')
-
-
-class RbacSPCertScenarioTest(RoleScenarioTest):
-
-    @ResourceGroupPreparer(name_prefix='cli_create_rbac_sp_with_cert')
-    def test_create_for_rbac_with_cert_no_assignment(self, resource_group):
-
-        self.kwargs.update({
-            'display_name': resource_group,
-        })
-
-        try:
-            with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
-                result = self.cmd('ad sp create-for-rbac -n {display_name} --create-cert',
-                                  checks=self.check('displayName', '{display_name}')).get_output_in_json()
-                self.kwargs['app_id'] = result['appId']
-
-                self.assertTrue(result['fileWithCertAndPrivateKey'].endswith('.pem'))
-
-                # On Linux or MacOS, check the cert file is a regular file (S_IFREG 0100000) with permission 600
-                # https://manpages.ubuntu.com/manpages/focal/man7/inode.7.html
-                # Windows doesn't have the Linux permission concept.
-                if sys.platform != 'win32':
-                    assert os.stat(result['fileWithCertAndPrivateKey']).st_mode == 0o100600
-
-                os.remove(result['fileWithCertAndPrivateKey'])
-
-                result = self.cmd('ad sp credential reset -n {app_id} --create-cert',
-                                  checks=self.check('name', '{app_id}')).get_output_in_json()
-                self.assertTrue(result['fileWithCertAndPrivateKey'].endswith('.pem'))
-
-                if sys.platform != 'win32':
-                    assert os.stat(result['fileWithCertAndPrivateKey']).st_mode == 0o100600
-
-                os.remove(result['fileWithCertAndPrivateKey'])
-        finally:
-            self.cmd('ad app delete --id {app_id}',
-                     checks=self.is_empty())
-
-
-class RbacSPKeyVaultScenarioTest2(ScenarioTest):
     @ResourceGroupPreparer(name_prefix='cli_test_sp_with_kv_new_cert')
     @KeyVaultPreparer(name_prefix='test-rbac-new-kv')
-    def test_create_for_rbac_with_new_kv_cert(self, resource_group, key_vault):
+    def test_create_for_rbac_create_cert_keyvault(self, resource_group, key_vault):
         KeyVaultErrorException = get_sdk(self.cli_ctx, ResourceType.DATA_KEYVAULT, 'models.key_vault_error#KeyVaultErrorException')
         subscription_id = self.get_subscription_id()
 
@@ -157,30 +79,24 @@ class RbacSPKeyVaultScenarioTest2(ScenarioTest):
         })
 
         time.sleep(5)  # to avoid 504(too many requests) on a newly created vault
+        with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
+            try:
+                result = self.cmd('ad sp create-for-rbac --create-cert '
+                                  '--keyvault {kv} --cert {cert} -n {display_name}').get_output_in_json()
+                self.kwargs['app_id'] = result['appId']
+            except KeyVaultErrorException:
+                if not self.is_live and not self.in_recording:
+                    pass  # temporary workaround for keyvault challenge handling was ignored under playback
+                else:
+                    raise
+            cer1 = self.cmd('keyvault certificate show --vault-name {kv} -n {cert}').get_output_in_json()['cer']
+            self.cmd('ad app credential reset --id {app_id} --create-cert --keyvault {kv} --cert {cert}')
+            cer2 = self.cmd('keyvault certificate show --vault-name {kv} -n {cert}').get_output_in_json()['cer']
+            self.assertTrue(cer1 != cer2)
 
-        try:
-            with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
-                try:
-                    result = self.cmd('ad sp create-for-rbac --create-cert '
-                                      '--keyvault {kv} --cert {cert} -n {display_name}').get_output_in_json()
-                    self.kwargs['app_id'] = result['appId']
-                except KeyVaultErrorException:
-                    if not self.is_live and not self.in_recording:
-                        pass  # temporary workaround for keyvault challenge handling was ignored under playback
-                    else:
-                        raise
-                cer1 = self.cmd('keyvault certificate show --vault-name {kv} -n {cert}').get_output_in_json()['cer']
-                self.cmd('ad sp credential reset -n {app_id} --create-cert --keyvault {kv} --cert {cert}')
-                cer2 = self.cmd('keyvault certificate show --vault-name {kv} -n {cert}').get_output_in_json()['cer']
-                self.assertTrue(cer1 != cer2)
-        finally:
-            self.cmd('ad app delete --id {app_id}')
-
-
-class RbacSPKeyVaultScenarioTest(ScenarioTest):
     @ResourceGroupPreparer(name_prefix='cli_test_sp_with_kv_existing_cert')
     @KeyVaultPreparer(name_prefix='test-rbac-exist-kv')
-    def test_create_for_rbac_with_existing_kv_cert(self, resource_group, key_vault):
+    def test_create_for_rbac_use_cert_keyvault(self, resource_group, key_vault):
 
         import time
         subscription_id = self.get_subscription_id()
@@ -203,7 +119,7 @@ class RbacSPKeyVaultScenarioTest(ScenarioTest):
                 result = self.cmd('ad sp create-for-rbac -n {display_name} --keyvault {kv} '
                                   '--cert {cert}').get_output_in_json()
                 self.kwargs['app_id'] = result['appId']
-            self.cmd('ad sp credential reset -n {app_id} --keyvault {kv} --cert {cert}')
+            self.cmd('ad app credential reset --id {app_id} --keyvault {kv} --cert {cert}')
         finally:
             try:
                 self.cmd('ad app delete --id {app_id}')
@@ -218,15 +134,63 @@ class RbacSPKeyVaultScenarioTest(ScenarioTest):
                 result = self.cmd('ad sp create-for-rbac --keyvault {kv} '
                                   '--cert {cert} -n {display_name2}').get_output_in_json()
                 self.kwargs['app_id2'] = result['appId']
-            self.cmd('ad sp credential reset -n {app_id2} --keyvault {kv} --cert {cert}')
+            self.cmd('ad app credential reset --id {app_id2} --keyvault {kv} --cert {cert}')
         finally:
             try:
                 self.cmd('ad app delete --id {app_id2}')
             except:
                 pass
 
+    @AllowLargeResponse()
+    @ResourceGroupPreparer(name_prefix='cli_sp_create_for_rbac')
+    def test_create_for_rbac_with_password_with_assignment(self, resource_group):
 
-class RoleCreateScenarioTest(RoleScenarioTest):
+        subscription_id = self.get_subscription_id()
+        self.kwargs.update({
+            'sub': subscription_id,
+            'scope': f'/subscriptions/{subscription_id}/resourceGroups/{resource_group}',
+            'role': 'Reader',
+            'display_name': resource_group
+        })
+
+        with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
+            result = self.cmd('ad sp create-for-rbac -n {display_name} --scopes {scope} --role {role}',
+                              checks=self.check('displayName', '{display_name}')).get_output_in_json()
+            self.kwargs['app_id'] = result['appId']
+            self.cmd('role assignment list --assignee {app_id} --resource-group {rg}',
+                     checks=[
+                         self.check("length([])", 1),
+                         self.check("[0].roleDefinitionName", '{role}'),
+                         self.check("[0].scope", '{scope}')
+                     ])
+            self.cmd('role assignment delete --assignee {app_id} -g {rg}',
+                     checks=self.is_empty())
+
+    def test_create_for_rbac_argument_error(self):
+        self.kwargs.update({
+            'scope': '/subscriptions/00000000-0000-0000-0000-000000000000',
+            'role': 'Reader',
+            'display_name': self.create_random_name('azure-cli-test-', 30)
+        })
+
+        # No role assignment argument
+        # Without this line, no recording YAML will be generated. Playing back this test will make it live and fail
+        # in CI because there is no logged in account.
+        self.kwargs['app_id'] = self.cmd(
+            'ad sp create-for-rbac --display-name {display_name}').get_output_in_json()['appId']
+
+        from azure.cli.core.azclierror import ArgumentUsageError
+
+        # Missing --role
+        with self.assertRaisesRegex(ArgumentUsageError, 'both'):
+            self.cmd('ad sp create-for-rbac --scopes {scope}')
+
+        # Missing --scopes
+        with self.assertRaisesRegex(ArgumentUsageError, 'both'):
+            self.cmd('ad sp create-for-rbac --role {role}')
+
+
+class RoleCreateScenarioTest(RoleScenarioTestBase):
 
     @AllowLargeResponse()
     def test_role_create_scenario(self):
@@ -283,7 +247,7 @@ class RoleCreateScenarioTest(RoleScenarioTest):
             retry(lambda: self.cmd('role definition list -n {role}', checks=self.is_empty()))
 
 
-class RoleAssignmentScenarioTest(RoleScenarioTest):
+class RoleAssignmentScenarioTest(RoleScenarioTestBase):
 
     @ResourceGroupPreparer(name_prefix='cli_role_assign')
     @AllowLargeResponse()
@@ -301,7 +265,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             result = self.cmd('ad user create --display-name tester123 --password Test123456789'
                               ' --user-principal-name {upn}').get_output_in_json()
             self.kwargs.update({
-                'user_id': result['objectId']})
+                'user_id': result['id']})
             time.sleep(15)  # By-design, it takes some time for RBAC system propagated with graph object change
 
             group = self.create_random_name('testgroup', 15)
@@ -311,7 +275,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             group_result = self.cmd(
                 'ad group create --display-name group123 --mail-nickname {group}').get_output_in_json()
             self.kwargs.update({
-                'group_id': group_result['objectId']})
+                'group_id': group_result['id']})
             self.cmd(
                 'ad group member add --group {group_id} --member-id {user_id}')
 
@@ -371,7 +335,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
                 with self.assertRaisesRegex(CLIError, "Cannot find user or service principal in graph database for 'fake'."):
                     self.cmd('role assignment create --assignee fake --role contributor')
             finally:
-                self.cmd('ad user delete --upn-or-object-id {upn}')
+                self.cmd('ad user delete --id {upn}')
 
     @ResourceGroupPreparer(name_prefix='cli_role_assign')
     @AllowLargeResponse()
@@ -381,23 +345,33 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
 
         self.kwargs['rg'] = resource_group
 
-        def _test_role_assignment(assignee_object_id, assignee_principal_type=None):
+        def _test_role_assignment(assignee_object_id, assignee_principal_type=None, graph_call_fails=False):
             self.kwargs['object_id'] = assignee_object_id
-            self.kwargs['principal_type'] = assignee_principal_type
+            self.kwargs['assignee_principal_type'] = assignee_principal_type
             # test role assignment on subscription level
 
-            with mock.patch('azure.graphrbac.operations.ObjectsOperations.get_objects_by_object_ids') \
-                    as get_objects_by_object_ids_mock:
-                if assignee_principal_type:
+            if assignee_principal_type:
+                # No graph call
+                with mock.patch('azure.cli.command_modules.role._msgrpah._graph_client.GraphClient.directory_object_get_by_ids') \
+                        as directory_object_get_by_ids_mock:
                     self.cmd(
                         'role assignment create --assignee-object-id {object_id} '
-                        '--assignee-principal-type {principal_type} --role Reader -g {rg}')
+                        '--assignee-principal-type {assignee_principal_type} --role Reader -g {rg}')
                     # Verify no graph call
-                    get_objects_by_object_ids_mock.assert_not_called()
+                    directory_object_get_by_ids_mock.assert_not_called()
+            else:
+                # Make graph call to resolve assignee_principal_type
+                if graph_call_fails:
+                    import requests
+                    mock_response = requests.Response()
+                    mock_response.status_code = 403
+                    mock_response.reason = 'Forbidden for url: https://...'
+                    with mock.patch(
+                            'azure.cli.command_modules.role._msgrpah._graph_client.GraphClient.directory_object_get_by_ids',
+                            side_effect=GraphError('403', mock_response)):
+                        self.cmd('role assignment create --assignee-object-id {object_id} --role Reader -g {rg}')
                 else:
                     self.cmd('role assignment create --assignee-object-id {object_id} --role Reader -g {rg}')
-                    # Verify 1 graph call to resolve principal type
-                    get_objects_by_object_ids_mock.assert_called_once()
 
             self.cmd('role assignment list -g {rg}', checks=self.check("length([])", 1))
             self.cmd('role assignment delete -g {rg}')
@@ -411,26 +385,21 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             _test_role_assignment(assignee_object_id)
 
             # test role assignment without principal type and graph call fail
-            from msrestazure.azure_exceptions import CloudError
-            import requests
-            mock_response = requests.Response()
-            mock_response.status_code = 403
-            mock_response.reason = 'Forbidden for url: https://graph.windows.net/.../getObjectsByObjectIds?api-version=1.6'
-            with mock.patch('azure.graphrbac.operations.ObjectsOperations.get_objects_by_object_ids',
-                            side_effect=CloudError(mock_response)):
-                _test_role_assignment(assignee_object_id)
+            _test_role_assignment(assignee_object_id, graph_call_fails=True)
 
         with mock.patch('azure.cli.command_modules.role.custom._gen_guid', side_effect=self.create_guid):
             # User
             user = self.create_random_name('testuser', 15)
             self.kwargs['upn'] = user + '@azuresdkteam.onmicrosoft.com'
 
-            result = self.cmd('ad user create --display-name tester123 --password Test123456789 --user-principal-name {upn}').get_output_in_json()
+            result = self.cmd('ad user create --display-name tester123 --password Test123456789 '
+                              '--user-principal-name {upn}').get_output_in_json()
+            time.sleep(30)
             try:
-                _test_role_assignment_graph_call(result['objectId'], 'User')
+                _test_role_assignment_graph_call(result['id'], 'User')
             finally:
                 try:
-                    self.cmd('ad user delete --upn-or-object-id {upn}')
+                    self.cmd('ad user delete --id {upn}')
                 except:
                     pass
 
@@ -438,9 +407,9 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             self.kwargs['group_name'] = self.create_random_name('testgroup', 15)
             result = self.cmd(
                 'ad group create --display-name {group_name} --mail-nickname {group_name}').get_output_in_json()
-            time.sleep(10)
+            time.sleep(30)
             try:
-                _test_role_assignment_graph_call(result['objectId'], 'Group')
+                _test_role_assignment_graph_call(result['id'], 'Group')
             finally:
                 try:
                     self.cmd('ad group delete --group {object_id}')
@@ -452,8 +421,9 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             result = self.cmd('ad sp create-for-rbac --name {sp_name}').get_output_in_json()
             self.kwargs['app_id'] = result['appId']
             result = self.cmd('ad sp show --id {app_id}').get_output_in_json()
+            time.sleep(30)
             try:
-                _test_role_assignment_graph_call(result['objectId'], 'ServicePrincipal')
+                _test_role_assignment_graph_call(result['id'], 'ServicePrincipal')
             finally:
                 try:
                     self.cmd('ad sp delete --id {object_id}')
@@ -477,7 +447,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             })
 
             result = self.cmd('ad user create --display-name tester123 --password Test123456789 --user-principal-name {upn}').get_output_in_json()
-            self.kwargs['object_id'] = result['objectId']
+            self.kwargs['object_id'] = result['id']
             try:
                 # Test create role assignment with description, condition and condition_version
                 self.cmd('role assignment create --assignee-object-id {object_id} --assignee-principal-type User --role reader -g {rg} '
@@ -531,7 +501,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
                 self.cmd('role assignment delete -g {rg}')
 
             finally:
-                self.cmd('ad user delete --upn-or-object-id {upn}')
+                self.cmd('ad user delete --id {upn}')
 
     @ResourceGroupPreparer(name_prefix='cli_role_assign')
     @AllowLargeResponse()
@@ -571,7 +541,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             finally:
                 self.cmd('configure --default group="" --scope local')
                 os.chdir(base_dir)
-                self.cmd('ad user delete --upn-or-object-id {upn}')
+                self.cmd('ad user delete --id {upn}')
 
     def test_role_assignment_empty_string_args(self):
         expected_msg = "{} can't be an empty string"
@@ -625,7 +595,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
             finally:
                 if mgmt_grp_created:
                     self.cmd('account management-group delete -n {mgmt_grp}')
-                self.cmd('ad user delete --upn-or-object-id {upn}')
+                self.cmd('ad user delete --id {upn}')
 
     @ResourceGroupPreparer(name_prefix='cli_role_audit')
     @AllowLargeResponse()
@@ -670,7 +640,7 @@ class RoleAssignmentScenarioTest(RoleScenarioTest):
                                                            x['principalName'] == self.kwargs['upn'])])
                 retry(check_changelogs, sleep_duration=60, max_retry=15)
             finally:
-                self.cmd('ad user delete --upn-or-object-id {upn}')
+                self.cmd('ad user delete --id {upn}')
 
 
 class RoleAssignmentListScenarioTest(ScenarioTest):
