@@ -9,7 +9,7 @@ from knack.help_files import helps  # pylint: disable=unused-import
 
 helps['security'] = """
 type: group
-short-summary: Manage your security posture with Azure Security Center.
+short-summary: Manage your security posture with Microsoft Defender for Cloud.
 """
 
 helps['security alert'] = """
@@ -59,6 +59,65 @@ examples:
         az security alert update -g "myRg" --location "centralus" -n "alertName" --status "activate"
 """
 
+helps['security alerts-suppression-rule'] = """
+type: group
+short-summary: View and manage alerts suppression rules.
+"""
+
+helps['security alerts-suppression-rule list'] = """
+type: command
+short-summary: List all alerts suppression rule on a subscription scope.
+examples:
+  - name: List alerts suppression rules.
+    text: >
+        az security alerts-suppression-rule list
+"""
+
+helps['security alerts-suppression-rule show'] = """
+type: command
+short-summary: Shows an alerts suppression rule.
+examples:
+  - name: Get an alerts suppression rule on a subscription scope.
+    text: >
+        az security alerts-suppression-rule show --rule-name RuleName
+"""
+
+helps['security alerts-suppression-rule update'] = """
+type: command
+short-summary: Updates or create an alerts suppression rule.
+examples:
+  - name: Create suppression rule with entities.
+    text: >
+        az security alerts-suppression-rule update --rule-name RuleName --alert-type "Test" --reason "Other" --comment "Test comment" --state "Enabled"
+"""
+
+helps['security alerts-suppression-rule delete'] = """
+type: command
+short-summary: Delete an alerts suppression rule.
+examples:
+  - name: Delete an alerts suppression rule.
+    text: >
+        az security alerts-suppression-rule delete --rule-name RuleName
+"""
+
+helps['security alerts-suppression-rule upsert_scope'] = """
+type: command
+short-summary: Update an alerts suppression rule with scope element.
+examples:
+  - name: Add "entities.host.dnsdomain" scope to an alerts suppression rule.
+    text: >
+        az security alerts-suppression-rule upsert_scope --field "entities.process.commandline" --contains-substring "example" --rule-name RuleName
+"""
+
+helps['security alerts-suppression-rule delete_scope'] = """
+type: command
+short-summary: Delete an alerts suppression rule scope.
+examples:
+  - name: Delete an alerts suppression rule scope.
+    text: >
+        az security alerts-suppression-rule delete_scope --rule-name RuleName --field "entities.process.commandline"
+"""
+
 helps['security atp'] = """
 type: group
 short-summary: View and manage Advanced Threat Protection settings.
@@ -69,6 +128,11 @@ type: group
 short-summary: View and manage Advanced Threat Protection settings for storage accounts.
 """
 
+helps['security atp cosmosdb'] = """
+type: group
+short-summary: View and manage Advanced Threat Protection settings for Cosmos DB accounts.
+"""
+
 helps['security atp storage show'] = """
 type: command
 short-summary: Display Advanced Threat Protection settings for a storage account.
@@ -78,6 +142,15 @@ examples:
         az security atp storage show --resource-group MyResourceGroup --storage-account MyStorageAccount
 """
 
+helps['security atp cosmosdb show'] = """
+type: command
+short-summary: Display Advanced Threat Protection settings for an Azure Cosmos DB account.
+examples:
+  - name: Retrieve Advanced Threat Protection settings for an Azure Cosmos DB account on a subscription scope.
+    text: >
+        az security atp cosmosdb show --resource-group MyResourceGroup --cosmosdb-account MyCosmosDbAccount
+"""
+
 helps['security atp storage update'] = """
 type: command
 short-summary: Toggle status of Advanced Threat Protection for a storage account.
@@ -90,6 +163,18 @@ examples:
         az security atp storage update --resource-group MyResourceGroup --storage-account MyStorageAccount --is-enabled false
 """
 
+helps['security atp cosmosdb update'] = """
+type: command
+short-summary: Toggle status of Advanced Threat Protection for an Azure Cosmos DB account.
+examples:
+  - name: Enable Advanced Threat Protection for an Azure Cosmos DB account on a subscription scope.
+    text: >
+        az security atp cosmosdb update --resource-group MyResourceGroup --cosmosdb-account MyCosmosDbAccount --is-enabled true
+  - name: Disable Advanced Threat Protection for an Azure Cosmos DB account on a subscription scope.
+    text: >
+        az security atp cosmosdb update --resource-group MyResourceGroup --cosmosdb-account MyCosmosDbAccount --is-enabled false
+"""
+
 helps['security va'] = """
 type: group
 short-summary: View Vulnerability Assessment.
@@ -386,23 +471,23 @@ examples:
 
 helps['security location'] = """
 type: group
-short-summary: Shows the Azure Security Center Home region location.
+short-summary: Shows the Microsoft Defender for Cloud Home region location.
 """
 
 helps['security location list'] = """
 type: command
-short-summary: Shows the Azure Security Center Home region location.
+short-summary: Shows the Microsoft Defender for Cloud Home region location.
 examples:
-  - name: Shows the Azure Security Center Home region location.
+  - name: Shows the Microsoft Defender for Cloud Home region location.
     text: >
         az security location list
 """
 
 helps['security location show'] = """
 type: command
-short-summary: Shows the Azure Security Center Home region location.
+short-summary: Shows the Microsoft Defender for Cloud Home region location.
 examples:
-  - name: Shows the Azure Security Center Home region location.
+  - name: Shows the Microsoft Defender for Cloud Home region location.
     text: >
         az security location show -n centralus
 """
