@@ -21,6 +21,9 @@ from azure.mgmt.security.models import (SecurityContact,
                                         RulesResultsInput,
                                         AlertSyncSettings,
                                         DataExportSettings,
+                                        AlertsSuppressionRule,
+                                        SuppressionAlertsScope,
+                                        ScopeElement,
                                         Automation,
                                         AutomationScope,
                                         AutomationSource,
@@ -31,7 +34,7 @@ from azure.mgmt.security.models import (SecurityContact,
                                         AutomationTriggeringRule)
 from azure.mgmt.security.models._security_center_enums import Enum69
 from azure.cli.core.commands.client_factory import get_subscription_id
-from azure.cli.core.azclierror import MutuallyExclusiveArgumentError
+from azure.cli.core.azclierror import (MutuallyExclusiveArgumentError)
 from msrestazure.tools import resource_id
 from msrestazure.azure_exceptions import CloudError
 from ._utils import (
@@ -114,6 +117,102 @@ def update_security_alert(client, location, resource_name, status, resource_grou
         if status == "Resolve":
             client.update_subscription_level_state_to_resolve(resource_name)
 
+# --------------------------------------------------------------------------------------------
+# Security Alerts Suppression Rule
+# --------------------------------------------------------------------------------------------
+
+
+def list_security_alerts_suppression_rule(client):
+
+    return client.list()
+
+
+def show_security_alerts_suppression_rule(client, rule_name):
+
+    return client.get(alerts_suppression_rule_name=rule_name)
+
+
+def delete_security_alerts_suppression_rule(client, rule_name):
+
+    return client.delete(alerts_suppression_rule_name=rule_name)
+
+
+def update_security_alerts_suppression_rule(client,
+                                            rule_name,
+                                            alert_type,
+                                            reason,
+                                            state,
+                                            expiration_date_utc=None,
+                                            comment=None):
+
+    from azure.core.exceptions import ResourceNotFoundError
+
+    current_rule = None
+    try:
+        current_rule = client.get(alerts_suppression_rule_name=rule_name)
+    except ResourceNotFoundError:
+        suppression_alerts_scope = None
+
+    if current_rule is not None:
+        suppression_alerts_scope = current_rule.suppression_alerts_scope
+
+    suppression_rule_data = AlertsSuppressionRule(name=rule_name,
+                                                  alert_type=alert_type,
+                                                  expiration_date_utc=expiration_date_utc,
+                                                  reason=reason, state=state,
+                                                  comment=comment,
+                                                  suppression_alerts_scope=suppression_alerts_scope)
+
+    return client.update(alerts_suppression_rule_name=rule_name, alerts_suppression_rule=suppression_rule_data)
+
+
+def upsert_security_alerts_suppression_rule_scope(client, rule_name, field, contains_substring=None, any_of=None):
+    from azure.cli.core.commands import upsert_to_collection
+
+    # get the parent object
+    parent_object = client.get(alerts_suppression_rule_name=rule_name)
+
+    if contains_substring is not None:
+        current_additional_properties = {'contains': contains_substring}
+    else:
+        current_additional_properties = {'in': any_of}
+    scope = ScopeElement(additional_properties=current_additional_properties, field=field)
+
+    if parent_object.suppression_alerts_scope is None:
+        parent_object.suppression_alerts_scope = SuppressionAlertsScope(all_of=[scope])
+    else:
+        # add the new child to the parent collection
+        upsert_to_collection(parent_object.suppression_alerts_scope, 'all_of', scope, 'field')
+
+    # update the parent object
+    result = client.update(alerts_suppression_rule_name=rule_name, alerts_suppression_rule=parent_object)
+
+    # return the child object
+    return next((x for x in result.suppression_alerts_scope.all_of if x.field.lower() == field.lower()), None)
+
+
+def delete_security_alerts_suppression_rule_scope(client, rule_name, field):
+    from azure.cli.core.azclierror import InvalidArgumentValueError
+    err_msg_field_not_found = 'The specified --field was not found in scope'
+
+    # get the parent object
+    parent_object = client.get(alerts_suppression_rule_name=rule_name)
+
+    if parent_object.suppression_alerts_scope is None:
+        raise InvalidArgumentValueError(err_msg_field_not_found)
+
+    item_to_remove = next((x for x in
+                           parent_object.suppression_alerts_scope.all_of if x.field.lower() == field.lower()), None)
+
+    if item_to_remove is None:
+        raise InvalidArgumentValueError(err_msg_field_not_found)
+
+    parent_object.suppression_alerts_scope.all_of.remove(item_to_remove)
+    if len(parent_object.suppression_alerts_scope.all_of) == 0:
+        parent_object.suppression_alerts_scope = None
+
+    return client.update(alerts_suppression_rule_name=rule_name, alerts_suppression_rule=parent_object)
+
 
 # --------------------------------------------------------------------------------------------
 # Security Settings
@@ -358,18 +457,29 @@ def delete_security_workspace_setting(client, resource_name):
 # Security ATP
 # --------------------------------------------------------------------------------------------
 
-def get_atp_setting(cmd, client, resource_group_name, storage_account_name):
+def get_storage_atp_setting(cmd, client, resource_group_name, storage_account_name):
 
-    return client.get(_construct_resource_id(cmd, resource_group_name, storage_account_name))
+    return client.get(_construct_storage_resource_id(cmd, resource_group_name, storage_account_name))
 
 
-def update_atp_setting(cmd, client, resource_group_name, storage_account_name, is_enabled):
+def get_cosmosdb_atp_setting(cmd, client, resource_group_name, cosmos_db_account_name):
 
-    return client.create(_construct_resource_id(cmd, resource_group_name, storage_account_name),
+    return client.get(_construct_cosmosdb_resource_id(cmd, resource_group_name, cosmos_db_account_name))
+
+
+def update_storage_atp_setting(cmd, client, resource_group_name, storage_account_name, is_enabled):
+
+    return client.create(_construct_storage_resource_id(cmd, resource_group_name, storage_account_name),
                          AdvancedThreatProtectionSetting(is_enabled=is_enabled))
 
 
-def _construct_resource_id(cmd, resource_group_name, storage_account_name):
+def update_cosmosdb_atp_setting(cmd, client, resource_group_name, cosmos_db_account_name, is_enabled):
+
+    return client.create(_construct_cosmosdb_resource_id(cmd, resource_group_name, cosmos_db_account_name),
+                         AdvancedThreatProtectionSetting(is_enabled=is_enabled))
+
+
+def _construct_storage_resource_id(cmd, resource_group_name, storage_account_name):
 
     return resource_id(
         subscription=get_subscription_id(cmd.cli_ctx),
@@ -379,6 +489,16 @@ def _construct_resource_id(cmd, resource_group_name, storage_account_name):
         name=storage_account_name)
 
 
+def _construct_cosmosdb_resource_id(cmd, resource_group_name, cosmos_db_account_name):
+
+    return resource_id(
+        subscription=get_subscription_id(cmd.cli_ctx),
+        resource_group=resource_group_name,
+        namespace='Microsoft.DocumentDb',
+        type='databaseAccounts',
+        name=cosmos_db_account_name)
+
+
 # --------------------------------------------------------------------------------------------
 # Sql Vulnerability Assessment
 # --------------------------------------------------------------------------------------------
