@@ -11,44 +11,60 @@ from azure.cli.core.profiles import ResourceType
 
 
 def load_command_table(self, _):
-    from azure.cli.command_modules.servicebus._client_factory import namespaces_mgmt_client_factory, \
-        queues_mgmt_client_factory, topics_mgmt_client_factory, subscriptions_mgmt_client_factory, \
-        rules_mgmt_client_factory, disaster_recovery_mgmt_client_factory, migration_mgmt_client_factory
+    from azure.cli.command_modules.servicebus._client_factory import (namespaces_mgmt_client_factory,
+                                                                      queues_mgmt_client_factory,
+                                                                      topics_mgmt_client_factory,
+                                                                      subscriptions_mgmt_client_factory,
+                                                                      rules_mgmt_client_factory,
+                                                                      disaster_recovery_mgmt_client_factory,
+                                                                      migration_mgmt_client_factory,
+                                                                      private_endpoint_connections_mgmt_client_factory,
+                                                                      private_link_mgmt_client_factory)
 
     sb_namespace_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#NamespacesOperations.{}',
-        client_factory=namespaces_mgmt_client_factory
-    )
+        client_factory=namespaces_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     sb_queue_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#QueuesOperations.{}',
-        client_factory=queues_mgmt_client_factory
-    )
+        client_factory=queues_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     sb_topic_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#TopicsOperations.{}',
-        client_factory=topics_mgmt_client_factory
-    )
+        client_factory=topics_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     sb_subscriptions_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#SubscriptionsOperations.{}',
-        client_factory=subscriptions_mgmt_client_factory
-    )
+        client_factory=subscriptions_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     sb_rule_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#RulesOperations.{}',
-        client_factory=rules_mgmt_client_factory
-    )
+        client_factory=rules_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     sb_geodr_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#DisasterRecoveryConfigsOperations.{}',
-        client_factory=disaster_recovery_mgmt_client_factory
-    )
+        client_factory=disaster_recovery_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     sb_migration_util = CliCommandType(
         operations_tmpl='azure.mgmt.servicebus.operations#MigrationConfigsOperations.{}',
-        client_factory=migration_mgmt_client_factory
-    )
+        client_factory=migration_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
+
+    sb_private_endpoints_util = CliCommandType(
+        operations_tmpl='azure.mgmt.servicebus.operations#PrivateEndpointConnectionsOperations.{}',
+        client_factory=private_endpoint_connections_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
+
+    sb_private_links_util = CliCommandType(
+        operations_tmpl='azure.mgmt.servicebus.operations#PrivateLinkResourcesOperations.{}',
+        client_factory=private_link_mgmt_client_factory,
+        resource_type=ResourceType.MGMT_SERVICEBUS)
 
     from ._validators import validate_subnet
 
@@ -63,7 +79,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_namespace_exists')
         g.generic_update_command('update', custom_func_name='cli_namespace_update', custom_func_type=servicebus_custom, setter_name='begin_create_or_update')
 
-    with self.command_group('servicebus namespace authorization-rule', sb_namespace_util, client_factory=namespaces_mgmt_client_factory) as g:
+    with self.command_group('servicebus namespace authorization-rule', sb_namespace_util, client_factory=namespaces_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_namespaceautho_create')
         g.show_command('show', 'get_authorization_rule')
         g.command('list', 'list_authorization_rules')
@@ -72,15 +88,33 @@ def load_command_table(self, _):
         g.command('delete', 'delete_authorization_rule')
         g.generic_update_command('update', getter_name='get_authorization_rule', setter_name='create_or_update_authorization_rule', custom_func_name='cli_namespaceautho_update')
 
+    with self.command_group('servicebus namespace private-endpoint-connection', sb_private_endpoints_util, resource_type=ResourceType.MGMT_SERVICEBUS,
+                            custom_command_type=servicebus_custom, is_preview=True,
+                            client_factory=private_endpoint_connections_mgmt_client_factory) as g:
+        from ._validators import validate_private_endpoint_connection_id
+        g.command('delete', 'begin_delete', confirmation=True, validator=validate_private_endpoint_connection_id)
+        g.show_command('show', 'get', validator=validate_private_endpoint_connection_id)
+        g.command('list', 'list', validator=validate_private_endpoint_connection_id)
+        g.custom_command('approve', 'approve_private_endpoint_connection',
+                         validator=validate_private_endpoint_connection_id)
+        g.custom_command('reject', 'reject_private_endpoint_connection',
+                         validator=validate_private_endpoint_connection_id)
+
+    with self.command_group('servicebus namespace private-link-resource', sb_private_links_util,
+                            resource_type=ResourceType.MGMT_SERVICEBUS) as g:
+        from azure.cli.core.commands.transform import gen_dict_to_list_transform
+        g.show_command('show', 'get', is_preview=True, min_api='2021-06-01-preview',
+                       transform=gen_dict_to_list_transform(key="value"))
+
 # Queue Region
-    with self.command_group('servicebus queue', sb_queue_util, client_factory=queues_mgmt_client_factory) as g:
+    with self.command_group('servicebus queue', sb_queue_util, client_factory=queues_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_sbqueue_create')
         g.show_command('show', 'get')
         g.command('list', 'list_by_namespace')
         g.command('delete', 'delete')
         g.generic_update_command('update', custom_func_name='cli_sbqueue_update')
 
-    with self.command_group('servicebus queue authorization-rule', sb_queue_util, client_factory=queues_mgmt_client_factory) as g:
+    with self.command_group('servicebus queue authorization-rule', sb_queue_util, client_factory=queues_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_queueautho_create')
         g.show_command('show', 'get_authorization_rule')
         g.command('list', 'list_authorization_rules')
@@ -90,14 +124,14 @@ def load_command_table(self, _):
         g.generic_update_command('update', getter_name='get_authorization_rule', setter_name='create_or_update_authorization_rule', custom_func_name='cli_namespaceautho_update')
 
 # Topic Region
-    with self.command_group('servicebus topic', sb_topic_util, client_factory=topics_mgmt_client_factory) as g:
+    with self.command_group('servicebus topic', sb_topic_util, client_factory=topics_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_sbtopic_create')
         g.show_command('show', 'get')
         g.command('list', 'list_by_namespace')
         g.command('delete', 'delete')
         g.generic_update_command('update', custom_func_name='cli_sbtopic_update')
 
-    with self.command_group('servicebus topic authorization-rule', sb_topic_util, client_factory=topics_mgmt_client_factory) as g:
+    with self.command_group('servicebus topic authorization-rule', sb_topic_util, client_factory=topics_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_topicautho_create')
         g.show_command('show', 'get_authorization_rule')
         g.command('list', 'list_authorization_rules')
@@ -107,7 +141,7 @@ def load_command_table(self, _):
         g.generic_update_command('update', getter_name='get_authorization_rule', setter_name='create_or_update_authorization_rule', custom_func_name='cli_namespaceautho_update')
 
 # Subscription Region
-    with self.command_group('servicebus topic subscription', sb_subscriptions_util, client_factory=subscriptions_mgmt_client_factory) as g:
+    with self.command_group('servicebus topic subscription', sb_subscriptions_util, client_factory=subscriptions_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_sbsubscription_create')
         g.show_command('show', 'get')
         g.command('list', 'list_by_topic')
@@ -115,7 +149,7 @@ def load_command_table(self, _):
         g.generic_update_command('update', custom_func_name='cli_sbsubscription_update')
 
 # Rules Region
-    with self.command_group('servicebus topic subscription rule', sb_rule_util, client_factory=rules_mgmt_client_factory) as g:
+    with self.command_group('servicebus topic subscription rule', sb_rule_util, client_factory=rules_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('create', 'cli_rules_create')
         g.show_command('show', 'get')
         g.command('list', 'list_by_subscriptions')
@@ -123,7 +157,7 @@ def load_command_table(self, _):
         g.generic_update_command('update', custom_func_name='cli_rules_update')
 
 # DisasterRecoveryConfigs Region
-    with self.command_group('servicebus georecovery-alias', sb_geodr_util, client_factory=disaster_recovery_mgmt_client_factory) as g:
+    with self.command_group('servicebus georecovery-alias', sb_geodr_util, client_factory=disaster_recovery_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('set', 'cli_georecovery_alias_create')
         g.show_command('show', 'get')
         g.command('list', 'list')
@@ -133,20 +167,20 @@ def load_command_table(self, _):
         g.command('delete', 'delete')
 
 # DisasterRecoveryConfigs Authorization Region
-    with self.command_group('servicebus georecovery-alias authorization-rule', sb_geodr_util, client_factory=disaster_recovery_mgmt_client_factory) as g:
+    with self.command_group('servicebus georecovery-alias authorization-rule', sb_geodr_util, client_factory=disaster_recovery_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.command('list', 'list_authorization_rules')
         g.show_command('show', 'get_authorization_rule')
         g.command('keys list', 'list_keys')
 
 # MigrationConfigs Region
-    with self.command_group('servicebus migration', sb_migration_util, client_factory=migration_mgmt_client_factory) as g:
+    with self.command_group('servicebus migration', sb_migration_util, client_factory=migration_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('start', 'cli_migration_start')
         g.custom_show_command('show', 'cli_migration_show')
         g.custom_command('complete', 'cli_migration_complete')
         g.command('abort', 'revert')
 
 # NetwrokRuleSet Region
-    with self.command_group('servicebus namespace network-rule', sb_namespace_util, client_factory=namespaces_mgmt_client_factory) as g:
+    with self.command_group('servicebus namespace network-rule', sb_namespace_util, client_factory=namespaces_mgmt_client_factory, resource_type=ResourceType.MGMT_SERVICEBUS) as g:
         g.custom_command('add', 'cli_networkrule_createupdate', validator=validate_subnet)
         g.command('list', 'get_network_rule_set')
         g.custom_command('remove', 'cli_networkrule_delete', validator=validate_subnet)
