@@ -15,11 +15,13 @@ from ._validators import (
 from ._resource_config import (
     RESOURCE,
     SOURCE_RESOURCES_PARAMS,
+    SOURCE_RESOURCES_CREATE_PARAMS,
     TARGET_RESOURCES_PARAMS,
     AUTH_TYPE_PARAMS,
     SUPPORTED_AUTH_TYPE,
     SUPPORTED_CLIENT_TYPE,
     TARGET_SUPPORT_SERVICE_ENDPOINT,
+    TARGET_SUPPORT_PRIVATE_ENDPOINT
 )
 from ._addon_factory import AddonFactory
 
@@ -54,6 +56,22 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
                                   "if '--id' is not specified.".format(required_args=str(required_args)))
             context.ignore('source_id')
 
+        # scope parameter
+        if source == RESOURCE.KubernetesCluster:
+            context.argument('scope', options_list=['--kube-namespace'], type=str, default='default',
+                             help="The kubernetes namespace where the connection information "
+                                  "will be saved into (as kubernetes secret).")
+            context.argument('enable_csi', options_list=['--enable-csi'], arg_type=get_three_state_flag(),
+                             help="Use keyvault as a secrets store via a CSI volume. "
+                                  "If specified, AuthType Arguments are not needed.")
+        elif source == RESOURCE.ContainerApp:
+            for arg, content in SOURCE_RESOURCES_CREATE_PARAMS.get(source).items():
+                context.argument(arg, options_list=content.get('options'), type=str, help=content.get('help'))
+            context.ignore('enable_csi')
+        else:
+            context.ignore('scope')
+            context.ignore('enable_csi')
+
     def add_auth_block(context, source, target):
         support_auth_types = SUPPORTED_AUTH_TYPE.get(source, {}).get(target, [])
         for auth_type in AUTH_TYPE_PARAMS:
@@ -83,6 +101,9 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
                          help='The resource id of target service. Required if {required_args} '
                               'are not specified.'.format(required_args=str(required_args)))
 
+        if target != RESOURCE.KeyVault:
+            context.ignore('enable_csi')
+
     def add_connection_name_argument(context, source):
         context.argument('connection_name', options_list=['--connection'], type=str,
                          help='Name of the {} connection.'.format(source.value), validator=validate_params)
@@ -109,11 +130,22 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
     def add_secret_store_argument(context):
         context.argument('key_vault_id', options_list=['--vault-id'], help='The id of key vault to store secret value')
 
-    def add_service_endpoint_argument(context):
-        context.argument('service_endpoint', options_list=['--service-endpoint'], arg_type=get_three_state_flag(),
-                         default=None, help='Connect target service by service endpoint. '
-                         'Source resource must be in the VNet and target SKU must support service endpoint feature. '
-                         'More virtual network solution(private link) for connection can be found on Azure Portal.')
+    def add_vnet_block(context, target):
+        if target not in TARGET_SUPPORT_SERVICE_ENDPOINT:
+            c.ignore('service_endpoint')
+        else:
+            context.argument('service_endpoint', options_list=['--service-endpoint'], arg_type=get_three_state_flag(),
+                             default=None, arg_group='NetworkSolution',
+                             help='Connect target service by service endpoint. Source resource must be in the VNet'
+                             ' and target SKU must support service endpoint feature.')
+
+        if target not in TARGET_SUPPORT_PRIVATE_ENDPOINT:
+            c.ignore('private_endpoint')
+        else:
+            context.argument('private_endpoint', options_list=['--private-endpoint'], arg_type=get_three_state_flag(),
+                             default=None, arg_group='NetworkSolution',
+                             help='Connect target service by private endpoint. '
+                             'The private endpoint in source virtual network must be created ahead.')
 
     def add_confluent_kafka_argument(context):
         context.argument('bootstrap_server', options_list=['--bootstrap-server'], help='Kafka bootstrap server url')
@@ -161,18 +193,14 @@ def load_arguments(self, _):  # pylint: disable=too-many-statements
                 add_auth_block(c, source, target)
                 add_new_addon_argument(c, source, target)
                 add_secret_store_argument(c)
-                add_service_endpoint_argument(c)
-                if target not in TARGET_SUPPORT_SERVICE_ENDPOINT:
-                    c.ignore('service_endpoint')
+                add_vnet_block(c, target)
             with self.argument_context('{} connection update {}'.format(source.value, target.value)) as c:
                 add_client_type_argument(c, source, target)
                 add_connection_name_argument(c, source)
                 add_source_resource_block(c, source)
                 add_auth_block(c, source, target)
                 add_secret_store_argument(c)
-                add_service_endpoint_argument(c)
-                if target not in TARGET_SUPPORT_SERVICE_ENDPOINT:
-                    c.ignore('service_endpoint')
+                add_vnet_block(c, target)
 
         # special target resource: independent implementation
         target = RESOURCE.ConfluentKafka
