@@ -30,6 +30,7 @@ from ._resource_config import (
     SOURCE_RESOURCES,
     TARGET_RESOURCES,
     SOURCE_RESOURCES_PARAMS,
+    SOURCE_RESOURCES_CREATE_PARAMS,
     TARGET_RESOURCES_PARAMS,
     AUTH_TYPE_PARAMS,
     SUPPORTED_AUTH_TYPE
@@ -63,6 +64,20 @@ def get_target_resource_name(cmd):
     return target
 
 
+def get_resource_type_by_id(resource_id):
+    '''Get source or target resource type by resource id
+    '''
+    target_type = None
+    all_resources = dict()
+    all_resources.update(SOURCE_RESOURCES)
+    all_resources.update(TARGET_RESOURCES)
+    for _type, _id in all_resources.items():
+        matched = re.match(get_resource_regex(_id), resource_id, re.IGNORECASE)
+        if matched:
+            target_type = _type
+    return target_type
+
+
 def get_resource_regex(resource):
     '''Replace '{...}' with '[^/]*' for regex matching
     '''
@@ -161,7 +176,7 @@ def get_client_type(cmd, namespace):
 
         return client_type
 
-    # fallback to use Dotnet as client type
+    # fallback to use None as client type
     client_type = None
     if 'webapp' in cmd.name:
         client_type = _infer_webapp(namespace.source_id)
@@ -170,7 +185,7 @@ def get_client_type(cmd, namespace):
 
     method = 'detected'
     if client_type is None:
-        client_type = CLIENT_TYPE.Dotnet
+        client_type = CLIENT_TYPE.Blank
         method = 'default'
 
     logger.warning('Client type is not specified, use %s one: --client-type %s', method, client_type.value)
@@ -187,7 +202,10 @@ def interactive_input(arg, hint):
         secret = prompt_pass('Password of database (--secret secret=): ')
         value = {
             'name': name,
-            'secret': secret,
+            'secret_info': {
+                'secret_type': 'rawValue',
+                'value': secret
+            },
             'auth_type': 'secret'
         }
         cmd_value = 'name={} secret={}'.format(name, '*' * len(secret))
@@ -368,6 +386,21 @@ def get_missing_source_args(cmd):
     return missing_args
 
 
+def get_missing_source_create_args(cmd, namespace):
+    '''Get source resource related args in create
+    '''
+    source = get_source_resource_name(cmd)
+    missing_args = dict()
+
+    args = SOURCE_RESOURCES_CREATE_PARAMS.get(source)
+    if args:
+        for arg, content in args.items():
+            if not getattr(namespace, arg, None):
+                missing_args[arg] = content
+
+    return missing_args
+
+
 def get_missing_target_args(cmd):
     '''Get target resource related args
     '''
@@ -387,6 +420,14 @@ def get_missing_auth_args(cmd, namespace):
     target = get_target_resource_name(cmd)
     missing_args = dict()
 
+    # when keyvault csi is enabled, auth_type is userIdentity without subs_id and client_id
+    if source == RESOURCE.KubernetesCluster and target == RESOURCE.KeyVault\
+            and getattr(namespace, 'enable_csi', None):
+        setattr(namespace, 'user_identity_auth_info', {
+            'auth_type': 'userAssignedIdentity'
+        })
+        return missing_args
+
     # check if there are auth_info related params
     auth_param_exist = False
     for _, params in AUTH_TYPE_PARAMS.items():
@@ -446,6 +487,7 @@ def validate_create_params(cmd, namespace):
     missing_args = dict()
     if not validate_source_resource_id(namespace):
         missing_args.update(get_missing_source_args(cmd))
+    missing_args.update(get_missing_source_create_args(cmd, namespace))
     if not validate_target_resource_id(namespace):
         missing_args.update(get_missing_target_args(cmd))
     missing_args.update(get_missing_auth_args(cmd, namespace))
@@ -494,6 +536,15 @@ def apply_source_args(cmd, namespace, arg_values):
         )
 
 
+def apply_source_create_args(cmd, namespace, arg_values):
+    '''Set source resource related args in create by arg_values
+    '''
+    source = get_source_resource_name(cmd)
+    for arg in SOURCE_RESOURCES_CREATE_PARAMS.get(source, {}):
+        if arg in arg_values:
+            setattr(namespace, arg, arg_values.get(arg, None))
+
+
 def apply_target_args(cmd, namespace, arg_values):
     '''Set target resource id by arg_values
     '''
@@ -543,6 +594,7 @@ def apply_create_params(cmd, namespace, arg_values):
     '''Set create command missing args
     '''
     apply_source_args(cmd, namespace, arg_values)
+    apply_source_create_args(cmd, namespace, arg_values)
     apply_target_args(cmd, namespace, arg_values)
     apply_auth_args(cmd, namespace, arg_values)
 
@@ -622,13 +674,14 @@ def validate_service_state(linker_parameters):
     '''Validate whether user provided params are applicable to service state
     '''
     target_type = None
+    target_id = linker_parameters.get('target_service', dict()).get('id')
     for target, resource_id in TARGET_RESOURCES.items():
-        matched = re.match(get_resource_regex(resource_id), linker_parameters.get('target_id'), re.IGNORECASE)
+        matched = re.match(get_resource_regex(resource_id), target_id, re.IGNORECASE)
         if matched:
             target_type = target
 
     if target_type == RESOURCE.AppConfig and linker_parameters.get('auth_info', dict()).get('auth_type') == 'secret':
-        segments = parse_resource_id(linker_parameters.get('target_id'))
+        segments = parse_resource_id(target_id)
         rg = segments.get('resource_group')
         name = segments.get('name')
         if not rg or not name:
