@@ -15,20 +15,21 @@ from azure.cli.core.azclierror import (
 from ._resource_config import (
     SUPPORTED_AUTH_TYPE,
     SUPPORTED_CLIENT_TYPE,
-    TARGET_RESOURCES,
-    TARGET_RESOURCES_USERTOKEN
+    TARGET_RESOURCES
 )
 from ._validators import (
     get_source_resource_name,
     get_target_resource_name,
+    get_resource_type_by_id,
     validate_service_state
 )
 from ._addon_factory import AddonFactory
 from ._utils import (
+    set_user_token_by_source_and_target,
     set_user_token_header,
     auto_register
 )
-# pylint: disable=unused-argument
+# pylint: disable=unused-argument,unsubscriptable-object,unsupported-membership-test
 
 
 logger = get_logger(__name__)
@@ -65,14 +66,15 @@ def connection_list_support_types(cmd, client,
     for target in supported_target_resources:
         auth_types = SUPPORTED_AUTH_TYPE.get(source).get(target)
         client_types = SUPPORTED_CLIENT_TYPE.get(source).get(target)
-        auth_types = [item.value for item in auth_types]
-        client_types = [item.value for item in client_types]
-        results.append({
-            'source': source.value,
-            'target': target.value,
-            'auth_types': auth_types,
-            'client_types': client_types
-        })
+        if auth_types and client_types:
+            auth_types = [item.value for item in auth_types]
+            client_types = [item.value for item in client_types]
+            results.append({
+                'source': source.value,
+                'target': target.value,
+                'auth_types': auth_types,
+                'client_types': client_types
+            })
 
     return results
 
@@ -131,20 +133,16 @@ def connection_validate(cmd, client,
                         cluster=None,
                         site=None,
                         spring=None, app=None, deployment='default'):
-    import re
-    from ._validators import get_resource_regex
-
     if not source_id or not connection_name:
         raise RequiredArgumentMissingError(err_msg.format('--source-id, --connection'))
 
     # HACK: get linker first to infer target resource type so that user token can be
     # set to work around OBO
     linker = todict(client.get(resource_uri=source_id, linker_name=connection_name))
-    target_id = linker.get('targetId')
-    for resource_type, resource_id in TARGET_RESOURCES.items():
-        matched = re.match(get_resource_regex(resource_id), target_id, re.IGNORECASE)
-        if matched and resource_type in TARGET_RESOURCES_USERTOKEN:
-            client = set_user_token_header(client, cmd.cli_ctx)
+    target_id = linker.get('targetService', dict()).get('id', '')
+    target_type = get_resource_type_by_id(target_id)
+    source_type = get_source_resource_name(cmd)
+    client = set_user_token_by_source_and_target(client, cmd.cli_ctx, source_type, target_type)
 
     return auto_register(client.begin_validate, resource_uri=source_id, linker_name=connection_name)
 
@@ -158,8 +156,9 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals
                       service_principal_auth_info_secret=None,
                       key_vault_id=None,
                       service_endpoint=None,
+                      private_endpoint=None,
                       new_addon=False, no_wait=False,
-                      cluster=None,
+                      cluster=None, scope=None, enable_csi=False,            # Resource.KubernetesCluster
                       site=None,                                             # Resource.WebApp
                       spring=None, app=None, deployment='default',           # Resource.SpringCloud
                       server=None, database=None,                            # Resource.*Postgres, Resource.*Sql*
@@ -192,35 +191,56 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals
     auth_info = all_auth_info[0] if len(all_auth_info) == 1 else None
 
     parameters = {
-        'target_id': target_id,
+        'target_service': {
+            "type": "AzureResource",
+            "id": target_id
+        },
         'auth_info': auth_info,
         'secret_store': {
             'key_vault_id': key_vault_id,
         },
-        'client_type': client_type
+        'client_type': client_type,
+        'scope': scope
     }
 
     # HACK: set user token to work around OBO
+    source_type = get_source_resource_name(cmd)
     target_type = get_target_resource_name(cmd)
-    if target_type in TARGET_RESOURCES_USERTOKEN:
-        client = set_user_token_header(client, cmd.cli_ctx)
+    client = set_user_token_by_source_and_target(client, cmd.cli_ctx, source_type, target_type)
 
     if key_vault_id:
         client = set_user_token_header(client, cmd.cli_ctx)
         from ._utils import create_key_vault_reference_connection_if_not_exist
         create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id)
+    elif auth_info['auth_type'] == 'secret' and 'secret_info' in auth_info \
+            and auth_info['secret_info']['secret_type'] == 'keyVaultSecretReference':
+        raise ValidationError('--vault-id must be provided to use secret-name')
 
     if service_endpoint:
         client = set_user_token_header(client, cmd.cli_ctx)
         parameters['v_net_solution'] = {
             'type': 'serviceEndpoint'
         }
+    if private_endpoint:
+        client = set_user_token_header(client, cmd.cli_ctx)
+        parameters['v_net_solution'] = {
+            'type': 'privateLink'
+        }
+
+    if enable_csi:
+        parameters['target_service']['resource_properties'] = {
+            'type': 'KeyVault',
+            'connect_as_kubernetes_csi_driver': enable_csi,
+        }
 
     if new_addon:
         addon = AddonFactory.get(target_type)(cmd, source_id)
-        target_id, auth_info = addon.provision()
-        parameters['target_id'] = target_id
-        parameters['auth_info'] = auth_info
+        target_id, default_auth_info = addon.provision()
+        parameters['target_service'] = {
+            "type": "AzureResource",
+            "id": target_id
+        }
+        parameters['auth_info'] = auth_info or default_auth_info
         logger.warning('Start creating the connection')
 
         try:
@@ -250,11 +270,12 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals
                       service_principal_auth_info_secret=None,
                       key_vault_id=None,
                       service_endpoint=None,
+                      private_endpoint=None,
                       no_wait=False,
-                      cluster=None,
+                      scope=None,
+                      cluster=None, enable_csi=False,                         # Resource.Kubernetes
                       site=None,                                              # Resource.WebApp
-                      deployment='default',
-                      spring=None, app=None):                                 # Resource.SpringCloud
+                      spring=None, app=None, deployment='default'):           # Resource.SpringCloud
 
     linker = todict(client.get(resource_uri=source_id, linker_name=connection_name))
 
@@ -291,31 +312,42 @@ def connection_update(cmd, client,  # pylint: disable=too-many-locals
         key_vault_id = key_vault_id or linker.get('secretStore').get('keyVaultId')
 
     parameters = {
-        'target_id': linker.get('targetId'),
+        'target_service': linker.get('targetService'),
         'auth_info': auth_info,
         'secret_store': {
             'key_vault_id': key_vault_id,
         },
         'client_type': client_type or linker.get('clientType'),
+        # scope can be updated in container app while cannot be updated in aks due to some limitations
+        'scope': scope or linker.get('scope')
     }
 
     # HACK: set user token to work around OBO
+    source_type = get_source_resource_name(cmd)
     target_type = get_target_resource_name(cmd)
-    if target_type in TARGET_RESOURCES_USERTOKEN:
-        client = set_user_token_header(client, cmd.cli_ctx)
+    client = set_user_token_by_source_and_target(client, cmd.cli_ctx, source_type, target_type)
 
     if key_vault_id:
         client = set_user_token_header(client, cmd.cli_ctx)
         from ._utils import create_key_vault_reference_connection_if_not_exist
         create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id)
+    elif auth_info['auth_type'] == 'secret' and 'secret_info' in auth_info \
+            and auth_info['secret_info']['secret_type'] == 'keyVaultSecretReference':
+        raise ValidationError('--vault-id must be provided to use secret-name')
 
     parameters['v_net_solution'] = linker.get('vNetSolution')
     if service_endpoint:
         parameters['v_net_solution'] = {
             'type': 'serviceEndpoint'
         }
+    if private_endpoint:
+        parameters['v_net_solution'] = {
+            'type': 'privateLink'
+        }
     elif service_endpoint is False and linker.get('vNetSolution').get('type') == 'serviceEndpoint':
         parameters['v_net_solution'] = None
+    elif private_endpoint is False and linker.get('vNetSolution').get('type') == 'privateLink':
+        parameters['v_net_solution'] = None
 
     return auto_register(sdk_no_wait, no_wait,
                          client.begin_create_or_update,
@@ -336,7 +368,7 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
                             client_type=None,
                             source_resource_group=None,
                             source_id=None,
-                            cluster=None,
+                            cluster=None, scope=None,          # Resource.Kubernetes
                             site=None,                         # Resource.WebApp
                             deployment='default',
                             spring=None, app=None):            # Resource.SpringCloud
@@ -355,16 +387,23 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
 
     # create bootstrap-server
     parameters = {
-        'target_id': bootstrap_server,
+        'target_service': {
+            "type": "ConfluentBootstrapServer",
+            "endpoint": bootstrap_server
+        },
         'auth_info': {
             'name': kafka_key,
-            'secret': kafka_secret,
+            'secret_info': {
+                'secret_type': 'rawValue',
+                'value': kafka_secret
+            },
             'auth_type': 'secret'
         },
         'secret_store': {
             'key_vault_id': key_vault_id,
         },
         'client_type': client_type,
+        'scope': scope
     }
     logger.warning('Start creating a connection for bootstrap server ...')
     server_linker = client.begin_create_or_update(resource_uri=source_id,
@@ -376,16 +415,23 @@ def connection_create_kafka(cmd, client,  # pylint: disable=too-many-locals
 
     # create schema registry
     parameters = {
-        'target_id': schema_registry,
+        'target_service': {
+            "type": "ConfluentSchemaRegistry",
+            "endpoint": schema_registry
+        },
         'auth_info': {
             'name': schema_key,
-            'secret': schema_secret,
+            'secret_info': {
+                'secret_type': 'rawValue',
+                'value': schema_secret
+            },
             'auth_type': 'secret'
         },
         'secret_store': {
             'key_vault_id': key_vault_id,
         },
         'client_type': client_type,
+        'scope': scope
     }
     logger.warning('Start creating a connection for schema registry ...')
     registry_linker = client.begin_create_or_update(resource_uri=source_id,
@@ -434,7 +480,7 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
             from ._utils import create_key_vault_reference_connection_if_not_exist
             create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id)
         parameters = {
-            'target_id': schema_registry or server_linker.get('targetId'),
+            'targetService': server_linker.get('targetService'),
             'auth_info': {
                 'name': schema_key or server_linker.get('authInfo').get('name'),
                 'secret': schema_secret,
@@ -444,7 +490,14 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
                 'key_vault_id': key_vault_id,
             },
             'client_type': client_type or server_linker.get('clientType'),
+            # scope does not support update due to aks solution's limitation
+            'scope': server_linker.get('scope')
         }
+        if schema_registry:
+            parameters['targetService'] = {
+                "type": "ConfluentSchemaRegistry",
+                "endpoint": schema_registry
+            }
     else:  # the bootstrap server connection
         if kafka_secret is None:
             raise ValidationError("'--kafka-secret' is required to update a bootstrap server connection")
@@ -460,7 +513,7 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
             from ._utils import create_key_vault_reference_connection_if_not_exist
             create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, key_vault_id)
         parameters = {
-            'target_id': bootstrap_server or schema_linker.get('targetId'),
+            'targetService': schema_linker.get('targetService'),
             'auth_info': {
                 'name': kafka_key or schema_linker.get('authInfo').get('name'),
                 'secret': kafka_secret,
@@ -471,6 +524,11 @@ def connection_update_kafka(cmd, client,  # pylint: disable=too-many-locals
             },
             'client_type': client_type or schema_linker.get('clientType'),
         }
+        if bootstrap_server:
+            parameters['targetService'] = {
+                "type": "ConfluentBootstrapServer",
+                "endpoint": bootstrap_server
+            }
 
     return client.begin_create_or_update(resource_uri=source_id,
                                          linker_name=connection_name,
