@@ -4,71 +4,18 @@
 # license information.
 # --------------------------------------------------------------------------
 
-import unittest
 from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.testsdk import (
     ScenarioTest,
     record_only,
     live_only
 )
-from azure.cli.testsdk.scenario_tests import RecordingProcessor
-from azure.cli.testsdk.scenario_tests.utilities import is_text_payload
 from azure.cli.command_modules.serviceconnector._resource_config import (
     RESOURCE,
     SOURCE_RESOURCES,
     TARGET_RESOURCES
 )
-
-
-class CredentialReplacer(RecordingProcessor):
-
-    def recursive_hide(self, props):
-        # hide sensitive data recursively
-        fake_content = 'hidden'
-        sensitive_data = ['password=', 'key=']
-
-        if isinstance(props, dict):
-            for key, val in props.items():
-                props[key] = self.recursive_hide(val)
-        elif isinstance(props, list):
-            for index, val in enumerate(props):
-                props[index] = self.recursive_hide(val)
-        elif isinstance(props, str):
-            for data in sensitive_data:
-                if data in props.lower():
-                    props = fake_content
-
-        return props
-
-    def process_request(self, request):
-        import json
-
-        # hide secrets in request body
-        if is_text_payload(request) and request.body and json.loads(request.body):
-            body = self.recursive_hide(json.loads(request.body))
-            request.body = json.dumps(body)
-
-        # hide token in header
-        if 'x-ms-cupertino-test-token' in request.headers:
-            request.headers['x-ms-cupertino-test-token'] = 'hidden'
-        if 'x-ms-serviceconnector-user-token' in request.headers:
-            request.headers['x-ms-serviceconnector-user-token'] = 'hidden'
-
-        return request
-
-    def process_response(self, response):
-        import json
-
-        if is_text_payload(response) and response['body']['string']:
-            try:
-                body = json.loads(response['body']['string'])
-                body = self.recursive_hide(body)
-                response['body']['string'] = json.dumps(body)
-            except Exception:
-                pass
-
-        return response
-
+from ._test_utils import CredentialReplacer
 
 class WebAppConnectionScenarioTest(ScenarioTest):
 
@@ -84,8 +31,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-config-app2',
-            'config_store': 'servicelinker-app-configuration2'
+            'site': 'servicelinker-config-app',
+            'config_store': 'servicelinker-app-configuration'
         })
 
         # prepare params
@@ -108,6 +55,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update appconfig --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -127,8 +78,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-win-group',
             'target_resource_group': 'servicelinker-test-win-group',
-            'site': 'servicelinker-cassandra-cosmos-asp-app2',
-            'account': 'servicelinker-cassandra-cosmos2',
+            'site': 'servicelinker-cassandra-cosmos-asp-app',
+            'account': 'servicelinker-cassandra-cosmos',
             'key_space': 'coredb'
         })
 
@@ -152,6 +103,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update cosmos-cassandra --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -171,8 +126,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-win-group',
             'target_resource_group': 'servicelinker-test-win-group',
-            'site': 'servicelinker-gremlin-cosmos-asp-app2',
-            'account': 'servicelinker-gremlin-cosmos2',
+            'site': 'servicelinker-gremlin-cosmos-asp-app',
+            'account': 'servicelinker-gremlin-cosmos',
             'database': 'coreDB',
             'graph': 'MyItem'
         })
@@ -197,6 +152,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update cosmos-gremlin --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -216,8 +175,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-win-group',
             'target_resource_group': 'servicelinker-test-win-group',
-            'site': 'servicelinker-mongo-cosmos-asp-app2',
-            'account': 'servicelinker-mongo-cosmos2',
+            'site': 'servicelinker-mongo-cosmos-asp-app',
+            'account': 'servicelinker-mongo-cosmos',
             'database': 'coreDB'
         })
 
@@ -241,6 +200,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update cosmos-mongo --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -260,8 +223,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-win-group',
             'target_resource_group': 'servicelinker-test-win-group',
-            'site': 'servicelinker-sql-cosmos-asp-app2',
-            'account': 'servicelinker-sql-cosmos2',
+            'site': 'servicelinker-sql-cosmos-asp-app',
+            'account': 'servicelinker-sql-cosmos',
             'database': 'coreDB'
         })
 
@@ -285,6 +248,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update cosmos-sql --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -304,8 +271,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-win-group',
             'target_resource_group': 'servicelinker-test-win-group',
-            'site': 'servicelinker-table-cosmos-asp-app2',
-            'account': 'servicelinker-table-cosmos2',
+            'site': 'servicelinker-table-cosmos-asp-app',
+            'account': 'servicelinker-table-cosmos',
             'table': 'MyItem'
         })
 
@@ -329,6 +296,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update cosmos-table --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -348,8 +319,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-eventhub-app2',
-            'namespace': 'servicelinkertesteventhub2'
+            'site': 'servicelinker-eventhub-app',
+            'namespace': 'servicelinkertesteventhub'
         })
 
         # prepare params
@@ -372,6 +343,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update eventhub --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -391,8 +366,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-servicebus-app2',
-            'namespace': 'servicelinkertestservicebus2'
+            'site': 'servicelinker-servicebus-app',
+            'namespace': 'servicelinkertestservicebus'
         })
 
         # prepare params
@@ -415,6 +390,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update servicebus --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -434,8 +413,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-signalr-app2',
-            'signalr': 'servicelinker-signalr2'
+            'site': 'servicelinker-signalr-app',
+            'signalr': 'servicelinker-signalr'
         })
 
         # prepare params
@@ -458,6 +437,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update signalr --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -501,6 +484,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update webpubsub --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -520,8 +507,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-keyvault-app2',
-            'vault': 'servicelinker-test-kv2'
+            'site': 'servicelinker-keyvault-app',
+            'vault': 'servicelinker-test-kv'
         })
 
         # prepare params
@@ -544,6 +531,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update keyvault --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -563,8 +554,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-flexiblepostgresql-app2',
-            'server': 'servicelinker-flexiblepostgresql2',
+            'site': 'servicelinker-flexiblepostgresql-app',
+            'server': 'servicelinker-flexiblepostgresql',
             'database': 'test'
         })
 
@@ -593,6 +584,11 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update postgres-flexible --id {} --client-type dotnet '
+                 '--secret name={} secret={}'.format(connection_id, user, password),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -637,6 +633,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update redis --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -681,6 +681,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update redis-enterprise --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -700,8 +704,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-mysql-app2',
-            'server': 'servicelinker-mysql2',
+            'site': 'servicelinker-mysql-app',
+            'server': 'servicelinker-mysql',
             'database': 'mysqlDB'
         })
 
@@ -730,6 +734,11 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update mysql --id {} --client-type dotnet '
+                 '--secret name={} secret={}'.format(connection_id, user, password),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -743,14 +752,14 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         self.cmd('webapp connection delete --id {} --yes'.format(connection_id))
 
 
-    @record_only()
+    # @record_only()
     def test_webapp_mysqlflexible_e2e(self):
         self.kwargs.update({
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-flexiblemysql-app2',
-            'server': 'servicelinker-flexible-mysql2',
+            'site': 'servicelinker-flexiblemysql-app',
+            'server': 'servicelinker-flexible-mysql',
             'database': 'mysqlDB'
         })
 
@@ -758,7 +767,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         user = 'servicelinker'
         password = self.cmd('keyvault secret show --vault-name cupertino-kv-test -n TestDbPassword')\
             .get_output_in_json().get('value')
-
+        keyvaultUri = "https://cupertino-kv-test.vault.azure.net/secrets/TestDbPassword"
+        
         # prepare params
         name = 'testconn'
         source_id = SOURCE_RESOURCES.get(RESOURCE.WebApp).format(**self.kwargs)
@@ -779,6 +789,11 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update mysql-flexible --id {} --client-type dotnet '
+                 '--secret name={} secret-uri={}'.format(connection_id, user, keyvaultUri),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -798,8 +813,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-postgresql-app2',
-            'server': 'servicelinker-postgresql2',
+            'site': 'servicelinker-postgresql-app',
+            'server': 'servicelinker-postgresql',
             'database': 'test'
         })
 
@@ -828,6 +843,11 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update postgres --id {} --client-type dotnet '
+                 '--secret name={} secret={}'.format(connection_id, user, password),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -877,6 +897,11 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update sql --id {} --client-type dotnet '
+                 '--secret name={} secret={}'.format(connection_id, user, password),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -896,8 +921,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-storageblob-app2',
-            'account': 'servicelinkerstorage2'
+            'site': 'servicelinker-storageblob-app',
+            'account': 'servicelinkerstorage'
         })
 
         # prepare params
@@ -920,6 +945,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update storage-blob --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -934,7 +963,7 @@ class WebAppConnectionScenarioTest(ScenarioTest):
 
 
     @live_only()
-    @unittest.skip('"run_cli_cmd" could only work at live mode, please comment it for live test')
+    # @unittest.skip('"run_cli_cmd" could only work at live mode, please comment it for live test')
     def test_webapp_storageblob_keyvault_ref(self):
         self.kwargs.update({
             'subscription': get_subscription_id(self.cli_ctx),
@@ -1029,7 +1058,6 @@ class WebAppConnectionScenarioTest(ScenarioTest):
                 self.check('vNetSolution.type', "serviceEndpoint"),
             ]
         ).get_output_in_json()
-        print(update_result)
 
         # update connection vnet solution
         self.cmd('webapp connection update storage-blob --id {} '
@@ -1045,6 +1073,67 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         for conn in self.cmd('webapp connection list --source-id {}'.format(source_id)).get_output_in_json():
             self.cmd('webapp connection delete --id {} --yes'.format(conn.get('id')))
 
+    @record_only()
+    def test_webapp_storageblob_vnet_pe(self):
+        self.kwargs.update({
+            'subscription': get_subscription_id(self.cli_ctx),
+            'source_resource_group': 'servicelinker-test-linux-group',
+            'target_resource_group': 'servicelinker-test-linux-group',
+            'site': 'servicelinker-storageblob-app',
+            'account': 'servicelinkerteststorage',
+        })
+
+        # prepare params
+        name = 'testconn'
+        source_id = SOURCE_RESOURCES.get(RESOURCE.WebApp).format(**self.kwargs)
+        target_id = TARGET_RESOURCES.get(
+            RESOURCE.StorageBlob).format(**self.kwargs)
+
+        # create connection
+        output = self.cmd('webapp connection create storage-blob --connection {} --source-id {} --target-id {} '
+                          '--secret --client-type python --private-endpoint'.format(name, source_id, target_id)).get_output_in_json()
+
+        id = output.get('id')
+        self.cmd(
+            'webapp connection list --source-id {}'.format(source_id),
+            checks=[
+                self.check('length(@)', 1),
+            ]
+        )
+
+        self.cmd(
+            'webapp connection show --id {}'.format(id),
+            checks=[
+                self.check('vNetSolution.type', "privateLink"),
+            ]
+        )
+
+        # update connection without vNetSolution
+        result = self.cmd('webapp connection update storage-blob --id {} '
+                          '--secret'.format(id)).get_output_in_json()
+
+        update_result = self.cmd(
+            'webapp connection show --id {}'.format(id),
+            checks=[
+                self.check('vNetSolution.type', "privateLink"),
+            ]
+        ).get_output_in_json()
+
+        # update connection vnet solution
+        self.cmd('webapp connection update storage-blob --id {} '
+                 '--secret --private-endpoint false'.format(id))
+
+        update_result = self.cmd(
+            'webapp connection show --id {}'.format(id),
+            checks=[
+                self.check('vNetSolution', None),
+            ]
+        ).get_output_in_json()
+
+        for conn in self.cmd('webapp connection list --source-id {}'.format(source_id)).get_output_in_json():
+            self.cmd(
+                'webapp connection delete --id {} --yes'.format(conn.get('id')))
+
 
 
 
@@ -1054,8 +1143,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-storagequeue-app2',
-            'account': 'servicelinkerstorage2'
+            'site': 'servicelinker-storagequeue-app',
+            'account': 'servicelinkerstorage'
         })
 
         # prepare params
@@ -1078,6 +1167,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update storage-queue --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -1097,8 +1190,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-storagefile-app2',
-            'account': 'servicelinkerstorage2'
+            'site': 'servicelinker-storagefile-app',
+            'account': 'servicelinkerstorage'
         })
 
         # prepare params
@@ -1121,6 +1214,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update storage-file --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -1140,8 +1237,8 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-storagetable-app2',
-            'account': 'servicelinkerstorage2'
+            'site': 'servicelinker-storagetable-app',
+            'account': 'servicelinkerstorage'
         })
 
         # prepare params
@@ -1164,6 +1261,10 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update storage-table --id {} --client-type dotnet'.format(connection_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -1183,7 +1284,7 @@ class WebAppConnectionScenarioTest(ScenarioTest):
             'subscription': get_subscription_id(self.cli_ctx),
             'source_resource_group': 'servicelinker-test-linux-group',
             'target_resource_group': 'servicelinker-test-linux-group',
-            'site': 'servicelinker-kafka-app2',
+            'site': 'servicelinker-kafka-app',
         })
 
         # prepare params
@@ -1206,6 +1307,11 @@ class WebAppConnectionScenarioTest(ScenarioTest):
         ).get_output_in_json()
         connection_id = connections[0].get('id')
 
+        # update connection
+        self.cmd('webapp connection update confluent-cloud --connection {} '
+                 '--source-id {} --client-type dotnet --kafka-secret Secret'.format(name, source_id),
+                 checks = [ self.check('clientType', 'dotnet') ])
+
         # list configuration
         self.cmd('webapp connection list-configuration --id {}'.format(connection_id))
 
@@ -1220,7 +1326,7 @@ class WebAppConnectionScenarioTest(ScenarioTest):
 
 
     @live_only()
-    @unittest.skip('"run_cli_cmd" could only work at live mode, please comment it for live test')
+    # @unittest.skip('"run_cli_cmd" could only work at live mode, please comment it for live test')
     def test_webapp_confluentkafka_keyvault_ref(self):
         self.kwargs.update({
             'subscription': get_subscription_id(self.cli_ctx),
