@@ -4,20 +4,16 @@
 # --------------------------------------------------------------------------------------------
 
 import os
+import sys
 from datetime import datetime
 
 from azure.cli.core.profiles import ResourceType, get_sdk
 from azure.cli.core.util import sdk_no_wait
 from azure.cli.core.azclierror import AzureResponseError
-from azure.cli.command_modules.storage.url_quote_util import encode_for_url, make_encoded_file_url_and_params
-from azure.cli.command_modules.storage.util import (create_blob_service_from_storage_client,
-                                                    create_file_share_from_storage_client,
-                                                    create_short_lived_share_sas,
-                                                    create_short_lived_container_sas,
-                                                    filter_none, collect_blobs, collect_blob_objects, collect_files,
-                                                    mkdir_p, guess_content_type, normalize_blob_file_path,
-                                                    check_precondition_success)
-from azure.core.exceptions import ResourceExistsError, ResourceModifiedError
+from azure.cli.command_modules.storage.util import (filter_none, collect_blobs, collect_blob_objects,
+                                                    collect_files_track2, mkdir_p, guess_content_type,
+                                                    normalize_blob_file_path, check_precondition_success)
+from azure.core.exceptions import ResourceExistsError, ResourceModifiedError, HttpResponseError
 
 from knack.log import get_logger
 from knack.util import CLIError
@@ -118,7 +114,6 @@ def list_container_rm(cmd, client, resource_group_name, account_name, include_de
 
 
 def container_rm_exists(client, resource_group_name, account_name, container_name):
-    from azure.core.exceptions import HttpResponseError
     try:
         container = client.get(resource_group_name=resource_group_name,
                                account_name=account_name, container_name=container_name)
@@ -129,35 +124,52 @@ def container_rm_exists(client, resource_group_name, account_name, container_nam
         raise err
 
 
-def create_container(cmd, container_name, resource_group_name=None, account_name=None,
+# pylint: disable=unused-argument
+def create_container(client, container_name, resource_group_name=None,
                      metadata=None, public_access=None, fail_on_exist=False, timeout=None,
-                     default_encryption_scope=None, prevent_encryption_scope_override=None, **kwargs):
+                     default_encryption_scope=None, prevent_encryption_scope_override=None):
+    encryption_scope = None
     if default_encryption_scope is not None or prevent_encryption_scope_override is not None:
-        from .._client_factory import storage_client_factory
-        client = storage_client_factory(cmd.cli_ctx).blob_containers
-        BlobContainer = cmd.get_models('BlobContainer', resource_type=ResourceType.MGMT_STORAGE)
-        blob_container = BlobContainer(default_encryption_scope=default_encryption_scope,
-                                       deny_encryption_scope_override=prevent_encryption_scope_override)
-        container = client.create(resource_group_name=resource_group_name, account_name=account_name,
-                                  container_name=container_name, blob_container=blob_container)
+        encryption_scope = {
+            'default_encryption_scope': default_encryption_scope,
+            'prevent_encryption_scope_override': prevent_encryption_scope_override
+        }
+    try:
+        container = client.create_container(container_name, metadata=metadata,
+                                            public_access=public_access,
+                                            container_encryption_scope=encryption_scope,
+                                            timeout=timeout)
         return container is not None
-
-    from .._client_factory import blob_data_service_factory
-    kwargs['account_name'] = account_name
-    client = blob_data_service_factory(cmd.cli_ctx, kwargs)
-    return client.create_container(container_name, metadata=metadata, public_access=public_access,
-                                   fail_on_exist=fail_on_exist, timeout=timeout)
+    except ResourceExistsError as ex:
+        if not fail_on_exist:
+            return False
+        raise ex
 
 
 def delete_container(client, container_name, fail_not_exist=False, lease_id=None, if_modified_since=None,
                      if_unmodified_since=None, timeout=None, bypass_immutability_policy=False,
                      processed_resource_group=None, processed_account_name=None, mgmt_client=None):
+    from azure.core.exceptions import ResourceNotFoundError
     if bypass_immutability_policy:
         mgmt_client.blob_containers.delete(processed_resource_group, processed_account_name, container_name)
         return True
-    return client.delete_container(
-        container_name, fail_not_exist=fail_not_exist, lease_id=lease_id, if_modified_since=if_modified_since,
-        if_unmodified_since=if_unmodified_since, timeout=timeout)
+    try:
+        client.delete_container(container_name, lease=lease_id,
+                                if_modified_since=if_modified_since,
+                                if_unmodified_since=if_unmodified_since,
+                                timeout=timeout)
+        return True
+    except ResourceNotFoundError as ex:
+        if not fail_not_exist:
+            return False
+        raise ex
+
+
+def set_container_permission(client, public_access=None, **kwargs):
+    acl_response = client.get_container_access_policy()
+    signed_identifiers = {} if not acl_response.get('signed_identifiers', None) else acl_response['signed_identifiers']
+    return client.set_container_access_policy(signed_identifiers=signed_identifiers,
+                                              public_access=public_access, **kwargs)
 
 
 def list_blobs(client, delimiter=None, include=None, marker=None, num_results=None, prefix=None,
@@ -207,7 +219,6 @@ def list_containers(client, include_metadata=False, include_deleted=False, marke
 
 def restore_blob_ranges(cmd, client, resource_group_name, account_name, time_to_restore, blob_ranges=None,
                         no_wait=False):
-
     if blob_ranges is None:
         BlobRestoreRange = cmd.get_models("BlobRestoreRange")
         blob_ranges = [BlobRestoreRange(start_range="", end_range="")]
@@ -228,18 +239,20 @@ def set_blob_tier(client, container_name, blob_name, tier, blob_type='block', ti
 
 
 def set_delete_policy(client, enable=None, days_retained=None):
-    policy = client.get_blob_service_properties().delete_retention_policy
+    policy = client.get_service_properties()['delete_retention_policy']
 
     if enable is not None:
         policy.enabled = enable == 'true'
     if days_retained is not None:
         policy.days = days_retained
+        if not 1 <= days_retained <= 365:
+            raise CLIError("Retention days must be greater than 0 and less than or equal to 365 days")
 
     if policy.enabled and not policy.days:
         raise CLIError("must specify days-retained")
 
-    client.set_blob_service_properties(delete_retention_policy=policy)
-    return client.get_blob_service_properties().delete_retention_policy
+    client.set_service_properties(delete_retention_policy=policy)
+    return client.get_service_properties()['delete_retention_policy']
 
 
 def set_immutability_policy(cmd, client, expiry_time=None, policy_mode=None, **kwargs):
@@ -290,11 +303,66 @@ def set_service_properties(client, parameters, delete_retention=None, delete_ret
     return client.get_blob_service_properties()
 
 
-def storage_blob_copy_batch(cmd, client, source_client, container_name=None,
-                            destination_path=None, source_container=None, source_share=None,
-                            source_sas=None, pattern=None, dryrun=False):
-    """Copy a group of blob or files to a blob container."""
+# pylint: disable=too-few-public-methods
+class BlobServiceProperties:
+    pass
 
+
+def transform_blob_generic_output(instance):
+    r = BlobServiceProperties()
+    for key in instance:
+        setattr(r, key, instance[key])
+    setattr(r, 'logging', getattr(r, 'analytics_logging'))
+    delattr(r, 'analytics_logging')
+    return r
+
+
+def set_service_properties_track2(client, parameters, delete_retention=None, delete_retention_period=None,
+                                  static_website=None, index_document=None, error_document_404_path=None):
+    # update
+    kwargs = {}
+    if hasattr(parameters, 'delete_retention_policy'):
+        kwargs['delete_retention_policy'] = parameters.delete_retention_policy
+    if delete_retention is not None:
+        parameters.delete_retention_policy.enabled = delete_retention
+    if delete_retention_period is not None:
+        parameters.delete_retention_policy.days = delete_retention_period
+
+    if hasattr(parameters, 'static_website'):
+        kwargs['static_website'] = parameters.static_website
+    if static_website is not None:
+        parameters.static_website.enabled = static_website
+    if index_document is not None:
+        parameters.static_website.index_document = index_document
+    if error_document_404_path is not None:
+        parameters.static_website.error_document404_path = error_document_404_path
+    if hasattr(parameters, 'hour_metrics'):
+        kwargs['hour_metrics'] = parameters.hour_metrics
+    if hasattr(parameters, 'logging'):
+        kwargs['analytics_logging'] = parameters.logging
+    if hasattr(parameters, 'minute_metrics'):
+        kwargs['minute_metrics'] = parameters.minute_metrics
+    if hasattr(parameters, 'cors'):
+        kwargs['cors'] = parameters.cors
+
+    if not parameters.hour_metrics.enabled:
+        parameters.hour_metrics.include_apis = None
+    if not parameters.minute_metrics.enabled:
+        parameters.minute_metrics.include_apis = None
+
+    # checks
+    policy = kwargs.get('delete_retention_policy', None)
+    if policy and policy.enabled and not policy.days:
+        raise CLIError("must specify days-retained")
+
+    client.set_service_properties(**kwargs)
+    return client.get_service_properties()
+
+
+def storage_blob_copy_batch(cmd, client, source_client, container_name=None, destination_path=None,
+                            source_container=None, source_share=None, source_sas=None, pattern=None, dryrun=False,
+                            source_account_name=None, source_account_key=None):
+    """Copy a group of blob or files to a blob container."""
     if dryrun:
         logger.warning('copy files or blobs to blob container')
         logger.warning('    account %s', client.account_name)
@@ -304,38 +372,25 @@ def storage_blob_copy_batch(cmd, client, source_client, container_name=None,
         logger.warning('    pattern %s', pattern)
         logger.warning(' operations')
 
-    source_sas = source_sas.lstrip('?') if source_sas else source_sas
     if source_container:
-        # copy blobs for blob container
-
-        # if the source client is None, recreate one from the destination client.
-        source_client = source_client or create_blob_service_from_storage_client(cmd, client)
-        if not source_sas:
-            source_sas = create_short_lived_container_sas(cmd, source_client.account_name, source_client.account_key,
-                                                          source_container)
-
+        # copy blobs for blob container, skip empty dir
         # pylint: disable=inconsistent-return-statements
         def action_blob_copy(blob_name):
             if dryrun:
                 logger.warning('  - copy blob %s', blob_name)
             else:
-                return _copy_blob_to_blob_container(client, source_client, container_name, destination_path,
-                                                    source_container, source_sas, blob_name)
-
+                return _copy_blob_to_blob_container(cmd, blob_service=client, source_blob_service=source_client,
+                                                    destination_container=container_name,
+                                                    destination_path=destination_path,
+                                                    source_container=source_container,
+                                                    source_blob_name=blob_name,
+                                                    source_sas=source_sas)
         return list(filter_none(action_blob_copy(blob) for blob in collect_blobs(source_client,
                                                                                  source_container,
                                                                                  pattern)))
 
     if source_share:
-        # copy blob from file share
-
-        # if the source client is None, recreate one from the destination client.
-        source_client = source_client or create_file_share_from_storage_client(cmd, client)
-
-        if not source_sas:
-            source_sas = create_short_lived_share_sas(cmd, source_client.account_name, source_client.account_key,
-                                                      source_share)
-
+        # copy blob from file share, skip empty dir
         # pylint: disable=inconsistent-return-statements
         def action_file_copy(file_info):
             dir_name, file_name = file_info
@@ -345,11 +400,10 @@ def storage_blob_copy_batch(cmd, client, source_client, container_name=None,
                 return _copy_file_to_blob_container(client, source_client, container_name, destination_path,
                                                     source_share, source_sas, dir_name, file_name)
 
-        return list(filter_none(action_file_copy(file) for file in collect_files(cmd,
-                                                                                 source_client,
-                                                                                 source_share,
-                                                                                 pattern)))
-    raise ValueError('Fail to find source. Neither blob container or file share is specified')
+        return list(filter_none(action_file_copy(file) for file in collect_files_track2(source_client,
+                                                                                        source_share,
+                                                                                        pattern)))
+    raise ValueError('Fail to find source. Neither blob container nor file share is specified')
 
 
 # pylint: disable=unused-argument
@@ -512,7 +566,6 @@ def transform_blob_type(cmd, blob_type):
 def _adjust_block_blob_size(client, blob_type, length):
     if not blob_type or blob_type != 'block' or length is None:
         return
-
     # increase the block size to 100MB when the block list will contain more than 50,000 blocks(each block 4MB)
     if length > 50000 * 4 * 1024 * 1024:
         client._config.max_block_size = 100 * 1024 * 1024
@@ -551,7 +604,7 @@ def upload_blob(cmd, client, file_path=None, container_name=None, blob_name=None
         upload_args['validate_content'] = validate_content
 
     if progress_callback:
-        upload_args['raw_response_hook'] = progress_callback
+        upload_args['progress_hook'] = progress_callback
 
     check_blob_args = {
         'if_modified_since': if_modified_since,
@@ -582,9 +635,15 @@ def upload_blob(cmd, client, file_path=None, container_name=None, blob_name=None
                                               **upload_args, **kwargs)
         if data is not None:
             _adjust_block_blob_size(client, blob_type, length)
-            response = client.upload_blob(data=data, length=length, metadata=metadata,
-                                          encryption_scope=encryption_scope,
-                                          **upload_args, **kwargs)
+            try:
+                response = client.upload_blob(data=data, length=length, metadata=metadata,
+                                              encryption_scope=encryption_scope,
+                                              **upload_args, **kwargs)
+            except UnicodeEncodeError:
+                response = client.upload_blob(data=data.encode('UTF-8', 'ignore').decode('UTF-8'),
+                                              length=length, metadata=metadata,
+                                              encryption_scope=encryption_scope,
+                                              **upload_args, **kwargs)
     except ResourceExistsError as ex:
         raise AzureResponseError(
             "{}\nIf you want to overwrite the existing one, please add --overwrite in your command.".format(ex.message))
@@ -606,7 +665,7 @@ def upload_blob(cmd, client, file_path=None, container_name=None, blob_name=None
     return response
 
 
-def download_blob(client, file_path, open_mode='wb', start_range=None, end_range=None,
+def download_blob(client, file_path=None, open_mode='wb', start_range=None, end_range=None,
                   progress_callback=None, **kwargs):
     offset = None
     length = None
@@ -614,12 +673,17 @@ def download_blob(client, file_path, open_mode='wb', start_range=None, end_range
         offset = start_range
         length = end_range - start_range + 1
     if progress_callback:
-        kwargs['raw_response_hook'] = progress_callback
+        kwargs['progress_hook'] = progress_callback
+    if not file_path:
+        kwargs['max_concurrency'] = 1
     download_stream = client.download_blob(offset=offset, length=length, **kwargs)
-    with open(file_path, open_mode) as stream:
+    if file_path:
+        with open(file_path, open_mode) as stream:
+            download_stream.readinto(stream)
+        return download_stream.properties
+    with os.fdopen(sys.stdout.fileno(), open_mode) as stream:
         download_stream.readinto(stream)
-
-    return download_stream.properties
+    return
 
 
 def get_block_ids(content_length, block_length):
@@ -691,12 +755,13 @@ def show_blob(cmd, client, container_name, blob_name, snapshot=None, lease_id=No
 def storage_blob_delete_batch(client, source, source_container_name, pattern=None, lease_id=None,
                               delete_snapshots=None, if_modified_since=None, if_unmodified_since=None, if_match=None,
                               if_none_match=None, timeout=None, dryrun=False):
+    container_client = client.get_container_client(source_container_name)
+
     @check_precondition_success
     def _delete_blob(blob_name):
         delete_blob_args = {
-            'container_name': source_container_name,
-            'blob_name': blob_name,
-            'lease_id': lease_id,
+            'blob': blob_name,
+            'lease': lease_id,
             'delete_snapshots': delete_snapshots,
             'if_modified_since': if_modified_since,
             'if_unmodified_since': if_unmodified_since,
@@ -704,7 +769,12 @@ def storage_blob_delete_batch(client, source, source_container_name, pattern=Non
             'if_none_match': if_none_match,
             'timeout': timeout
         }
-        return client.delete_blob(**delete_blob_args)
+        try:
+            container_client.delete_blob(**delete_blob_args)
+            return blob_name
+        except HttpResponseError as ex:
+            logger.debug(ex.exc_msg)
+            return None
 
     source_blobs = list(collect_blob_objects(client, source_container_name, pattern))
 
@@ -714,8 +784,8 @@ def storage_blob_delete_batch(client, source, source_container_name, pattern=Non
         if_modified_since_utc = if_modified_since.replace(tzinfo=timezone.utc) if if_modified_since else None
         if_unmodified_since_utc = if_unmodified_since.replace(tzinfo=timezone.utc) if if_unmodified_since else None
         for blob in source_blobs:
-            if not if_modified_since or blob[1].properties.last_modified >= if_modified_since_utc:
-                if not if_unmodified_since or blob[1].properties.last_modified <= if_unmodified_since_utc:
+            if not if_modified_since or blob[1].last_modified >= if_modified_since_utc:
+                if not if_unmodified_since or blob[1].last_modified <= if_unmodified_since_utc:
                     delete_blobs.append(blob[0])
         logger.warning('delete action: from %s', source)
         logger.warning('    pattern %s', pattern)
@@ -726,7 +796,7 @@ def storage_blob_delete_batch(client, source, source_container_name, pattern=Non
             logger.warning('  - %s', blob)
         return []
 
-    results = [result for include, result in (_delete_blob(blob[0]) for blob in source_blobs) if include]
+    results = [result for (include, result) in (_delete_blob(blob[0]) for blob in source_blobs) if result]
     num_failures = len(source_blobs) - len(results)
     if num_failures:
         logger.warning('%s of %s blobs not deleted due to "Failed Precondition"', num_failures, len(source_blobs))
@@ -775,8 +845,8 @@ def generate_sas_blob_uri(cmd, client, permission=None, expiry=None, start=None,
 
     if full_uri:
         blob_client = t_blob_client(account_url=client.url, container_name=container_name, blob_name=blob_name,
-                                    snapshot=snapshot, credential=sas_token)
-        return encode_url_path(blob_client.url)
+                                    snapshot=snapshot, credential=quote(sas_token, safe='&%()$=\',~'))
+        return encode_url_path(blob_client.url, safe='/()$=\',~%')
     return quote(sas_token, safe='&%()$=\',~')
 
 
@@ -785,7 +855,6 @@ def generate_container_shared_access_signature(cmd, client, container_name, perm
                                                start=None, id=None, ip=None, protocol=None, cache_control=None,
                                                content_disposition=None, content_encoding=None, content_language=None,
                                                content_type=None, as_user=False, **kwargs):
-
     t_generate_container_sas = get_sdk(cmd.cli_ctx, ResourceType.DATA_STORAGE_BLOB,
                                        '_shared_access_signature#generate_container_sas')
 
@@ -806,45 +875,57 @@ def generate_container_shared_access_signature(cmd, client, container_name, perm
                                     content_language=content_language, content_type=content_type, **kwargs)
 
 
-def create_blob_url(client, container_name, blob_name, protocol=None, snapshot=None):
-    return client.make_blob_url(
-        container_name, blob_name, protocol=protocol, snapshot=snapshot, sas_token=client.sas_token)
+def create_blob_url(client, container_name, blob_name, snapshot, protocol='https'):
+    if blob_name:
+        blob_client = client.get_blob_client(container=container_name, blob=blob_name, snapshot=snapshot)
+        url = blob_client.url
+    else:
+        container_client = client.get_container_client(container=container_name)
+        url = container_client.url + '/'
+    if protocol == 'http':
+        return url.replace('https', 'http', 1)
+    return url
 
 
-def _copy_blob_to_blob_container(blob_service, source_blob_service, destination_container, destination_path,
-                                 source_container, source_sas, source_blob_name):
-    from azure.common import AzureException
-    source_blob_url = source_blob_service.make_blob_url(source_container, encode_for_url(source_blob_name),
-                                                        sas_token=source_sas)
+def _copy_blob_to_blob_container(cmd, blob_service, source_blob_service, destination_container, destination_path,
+                                 source_container, source_blob_name, source_sas):
+    t_blob_client = cmd.get_models('_blob_client#BlobClient')
+    source_client = t_blob_client(account_url=source_blob_service.url, container_name=source_container,
+                                  blob_name=source_blob_name, credential=source_sas)
+    source_blob_url = source_client.url
+
     destination_blob_name = normalize_blob_file_path(destination_path, source_blob_name)
     try:
-        blob_service.copy_blob(destination_container, destination_blob_name, source_blob_url)
-        return blob_service.make_blob_url(destination_container, destination_blob_name)
-    except AzureException:
-        error_template = 'Failed to copy blob {} to container {}.'
-        raise CLIError(error_template.format(source_blob_name, destination_container))
+        blob_client = blob_service.get_blob_client(container=destination_container, blob=destination_blob_name)
+        blob_client.start_copy_from_url(source_url=source_blob_url, incremental_copy=False)
+        return blob_client.url
+    except HttpResponseError as ex:
+        if 'One of the request inputs is not valid' in str(ex):
+            # ignore error when copy from Data Lake Gen2 to Data Lake Gen2 and source blob is directory
+            pass
+        else:
+            error_template = 'Failed to copy blob {} to container {}. {}'
+            raise CLIError(error_template.format(source_blob_name, destination_container, ex))
 
 
 def _copy_file_to_blob_container(blob_service, source_file_service, destination_container, destination_path,
                                  source_share, source_sas, source_file_dir, source_file_name):
-    from azure.common import AzureException
-    file_url, source_file_dir, source_file_name = \
-        make_encoded_file_url_and_params(source_file_service, source_share, source_file_dir,
-                                         source_file_name, source_sas)
+    t_share_client = source_file_service.get_share_client(source_share)
+    t_file_client = t_share_client.get_file_client(os.path.join(source_file_dir, source_file_name))
+    source_file_url = '{}?{}'.format(t_file_client.url, source_sas)
 
     source_path = os.path.join(source_file_dir, source_file_name) if source_file_dir else source_file_name
     destination_blob_name = normalize_blob_file_path(destination_path, source_path)
-
     try:
-        blob_service.copy_blob(destination_container, destination_blob_name, file_url)
-        return blob_service.make_blob_url(destination_container, destination_blob_name)
-    except AzureException as ex:
-        error_template = 'Failed to copy file {} to container {}. {}'
-        raise CLIError(error_template.format(source_file_name, destination_container, ex))
+        blob_client = blob_service.get_blob_client(container=destination_container, blob=destination_blob_name)
+        blob_client.start_copy_from_url(source_url=source_file_url, incremental_copy=False)
+        return blob_client.url
+    except HttpResponseError as ex:
+        error_template = 'Failed to copy share {} to container {}. {}'
+        raise CLIError(error_template.format(source_path, destination_container, ex))
 
 
 def show_blob_v2(cmd, client, lease_id=None, **kwargs):
-
     blob = client.get_blob_properties(lease=lease_id, **kwargs)
 
     page_ranges = None
@@ -899,7 +980,6 @@ def add_progress_callback_v2(cmd, namespace):
 
 
 def query_blob(client, query_expression, input_config=None, output_config=None, result_file=None, **kwargs):
-
     reader = client.query_blob(query_expression=query_expression, blob_format=input_config, output_format=output_config,
                                **kwargs)
 
@@ -916,3 +996,11 @@ def copy_blob(client, source_url, metadata=None, **kwargs):
     if not kwargs['requires_sync']:
         kwargs.pop('requires_sync')
     return client.start_copy_from_url(source_url=source_url, metadata=metadata, incremental_copy=False, **kwargs)
+
+
+def exists(client, container_name, blob_name, snapshot, timeout):
+    if blob_name:
+        client = client.get_blob_client(container=container_name, blob=blob_name, snapshot=snapshot)
+    else:
+        client = client.get_container_client(container=container_name)
+    return client.exists(timeout=timeout)
