@@ -10,12 +10,13 @@ Commands for storage file share operations
 import os
 from knack.log import get_logger
 
-from azure.cli.command_modules.storage.util import (filter_none, collect_blobs, collect_files,
-                                                    create_blob_service_from_storage_client,
-                                                    create_short_lived_container_sas, create_short_lived_share_sas,
+from azure.cli.command_modules.storage.util import (filter_none, collect_blobs, collect_files_track2,
                                                     guess_content_type)
-from azure.cli.command_modules.storage.url_quote_util import encode_for_url, make_encoded_file_url_and_params
-from azure.cli.core.profiles import ResourceType
+from azure.cli.core.profiles import ResourceType, get_sdk
+from azure.core.exceptions import HttpResponseError, ResourceNotFoundError, ResourceExistsError
+from .fileshare import _get_client
+
+logger = get_logger(__name__)
 
 
 def create_share_rm(cmd, client, resource_group_name, account_name, share_name, metadata=None, share_quota=None,
@@ -107,35 +108,57 @@ def create_share_url(client, share_name, unc=None, protocol=None):
     return url
 
 
-def create_file_url(client, share_name, directory_name, file_name, protocol=None):
-    return client.make_file_url(
-        share_name, directory_name, file_name, protocol=protocol, sas_token=client.sas_token)
+def create_file_url(client, protocol=None, **kwargs):
+    client = _get_client(client, kwargs)
+    url = client.url
+    if url.endswith(client.share_name):
+        url = url + '/'
+    if protocol == 'http':
+        return url.replace('https', 'http', 1)
+    return url
 
 
-def list_share_files(cmd, client, share_name, directory_name=None, timeout=None, exclude_dir=False, snapshot=None,
+def list_share_files(cmd, client, directory_name=None, timeout=None, exclude_dir=False, exclude_extended_info=False,
                      num_results=None, marker=None):
-    if cmd.supported_api_version(min_api='2017-04-17'):
-        generator = client.list_directories_and_files(
-            share_name, directory_name, timeout=timeout, num_results=num_results, marker=marker, snapshot=snapshot)
-    else:
-        generator = client.list_directories_and_files(
-            share_name, directory_name, timeout=timeout, num_results=num_results, marker=marker)
+    from ..track2_util import list_generator
+    include = [] if exclude_extended_info else ["timestamps", "Etag", "Attributes", "PermissionKey"]
+    generator = client.list_directories_and_files(directory_name=directory_name, include=include,
+                                                  timeout=timeout, results_per_page=num_results)
+    pages = generator.by_page(continuation_token=marker)
+    results = list_generator(pages=pages, num_results=num_results)
+
+    if pages.continuation_token:
+        logger.warning('Next Marker:')
+        logger.warning(pages.continuation_token)
 
     if exclude_dir:
-        t_file_properties = cmd.get_models('file.models#FileProperties')
-
-        return list(f for f in generator if isinstance(f.properties, t_file_properties))
-
-    return generator
+        t_file_properties = cmd.get_models('_models#FileProperties', resource_type=ResourceType.DATA_STORAGE_FILESHARE)
+        return list(f for f in results if isinstance(f, t_file_properties))
+    return results
 
 
-def close_handle(client, share_name, close_all=None, directory_name=None, file_name=None, recursive=None,
-                 handle_id=None, marker=None, snapshot=None, timeout=None):
-    if close_all:
-        return client.close_handles(share_name, directory_name=directory_name, file_name=file_name, recursive=recursive,
-                                    handle_id='*', marker=marker, snapshot=snapshot, timeout=timeout)
-    return client.close_handles(share_name, directory_name=directory_name, file_name=file_name, recursive=recursive,
-                                handle_id=handle_id, marker=marker, snapshot=snapshot, timeout=timeout)
+def storage_file_upload(client, local_file_path, content_settings=None,
+                        metadata=None, validate_content=False, progress_callback=None, max_connections=2, timeout=None):
+    upload_args = {
+        'content_settings': content_settings,
+        'metadata': metadata,
+        'validate_content': validate_content,
+        'max_concurrency': max_connections,
+        'timeout': timeout
+    }
+    if progress_callback:
+        upload_args['raw_response_hook'] = progress_callback
+    # Because the contents of the uploaded file may be too large, it should be passed into the a stream object,
+    # upload_file() read file data in batches to avoid OOM problems
+    count = os.path.getsize(local_file_path)
+    with open(local_file_path, 'rb') as stream:
+        response = client.upload_file(data=stream, length=count, **upload_args)
+
+    if 'content_md5' in response:
+        if isinstance(response['content_md5'], bytearray):
+            response['content_md5'] = ''.join(hex(x) for x in response['content_md5'])
+
+    return response
 
 
 def storage_file_upload_batch(cmd, client, destination, source, destination_path=None, pattern=None, dryrun=False,
@@ -146,38 +169,41 @@ def storage_file_upload_batch(cmd, client, destination, source, destination_path
     from azure.cli.command_modules.storage.util import glob_files_locally, normalize_blob_file_path
 
     source_files = list(glob_files_locally(source, pattern))
-    logger = get_logger(__name__)
-    settings_class = cmd.get_models('file.models#ContentSettings')
+    settings_class = cmd.get_models('_models#ContentSettings')
 
     if dryrun:
         logger.info('upload files to file share')
         logger.info('    account %s', client.account_name)
         logger.info('      share %s', destination)
         logger.info('      total %d', len(source_files))
-        return [{'File': client.make_file_url(destination, os.path.dirname(dst) or None, os.path.basename(dst)),
+        dst = None
+        kwargs = {
+            'dir_name': os.path.dirname(dst),
+            'file_name': os.path.basename(dst)
+        }
+
+        return [{'File': create_file_url(client, **kwargs),
                  'Type': guess_content_type(src, content_settings, settings_class).content_type} for src, dst in
                 source_files]
 
     # TODO: Performance improvement
     # 1. Upload files in parallel
-    def _upload_action(src, dst):
-        dst = normalize_blob_file_path(destination_path, dst)
-        dir_name = os.path.dirname(dst)
-        file_name = os.path.basename(dst)
+    def _upload_action(src, dst2):
+        dst2 = normalize_blob_file_path(destination_path, dst2)
+        dir_name = os.path.dirname(dst2)
+        file_name = os.path.basename(dst2)
 
-        _make_directory_in_files_share(client, destination, dir_name)
-        create_file_args = {'share_name': destination, 'directory_name': dir_name, 'file_name': file_name,
-                            'local_file_path': src, 'progress_callback': progress_callback,
-                            'content_settings': guess_content_type(src, content_settings, settings_class),
-                            'metadata': metadata, 'max_connections': max_connections}
-
-        if cmd.supported_api_version(min_api='2016-05-31'):
-            create_file_args['validate_content'] = validate_content
+        _make_directory_in_files_share(client, destination, dir_name, V2=True)
 
         logger.warning('uploading %s', src)
-        client.create_file_from_path(**create_file_args)
+        storage_file_upload(client.get_file_client(dst2), src, content_settings, metadata, validate_content,
+                            progress_callback, max_connections)
 
-        return client.make_file_url(destination, dir_name, file_name)
+        args = {
+            'dir_name': dir_name,
+            'file_name': file_name
+        }
+        return create_file_url(client, **args)
 
     return list(_upload_action(src, dst) for src, dst in source_files)
 
@@ -195,7 +221,6 @@ def storage_file_download_batch(cmd, client, source, destination, pattern=None,
     if dryrun:
         source_files_list = list(source_files)
 
-        logger = get_logger(__name__)
         logger.warning('download files from file share')
         logger.warning('    account %s', client.account_name)
         logger.warning('      share %s', source)
@@ -225,19 +250,27 @@ def storage_file_download_batch(cmd, client, source, destination, pattern=None,
     return list(_download_action(f) for f in source_files)
 
 
-def storage_file_copy_batch(cmd, client, source_client, destination_share=None, destination_path=None,
+def storage_file_copy(client, copy_source, **kwargs):
+    result = client.start_copy_from_url(source_url=copy_source, **kwargs)
+    result['id'] = result['copy_id']
+    result['status'] = result['copy_status']
+    del result['copy_id']
+    del result['copy_status']
+    return result
+
+
+def storage_file_copy_batch(cmd, client, source_client, share_name=None, destination_path=None,
                             source_container=None, source_share=None, source_sas=None, pattern=None, dryrun=False,
-                            metadata=None, timeout=None):
+                            metadata=None, timeout=None, **kwargs):
     """
     Copy a group of files asynchronously
     """
-    logger = None
     if dryrun:
-        logger = get_logger(__name__)
         logger.warning('copy files or blobs to file share')
         logger.warning('    account %s', client.account_name)
-        logger.warning('      share %s', destination_share)
+        logger.warning('      share %s', share_name)
         logger.warning('       path %s', destination_path)
+        logger.warning('    source account %s', kwargs.get('source_account_name', ""))
         logger.warning('     source %s', source_container or source_share)
         logger.warning('source type %s', 'blob' if source_container else 'file')
         logger.warning('    pattern %s', pattern)
@@ -246,23 +279,16 @@ def storage_file_copy_batch(cmd, client, source_client, destination_share=None,
     if source_container:
         # copy blobs to file share
 
-        # if the source client is None, recreate one from the destination client.
-        source_client = source_client or create_blob_service_from_storage_client(cmd, client)
-
         # the cache of existing directories in the destination file share. the cache helps to avoid
         # repeatedly create existing directory so as to optimize the performance.
         existing_dirs = set([])
 
-        if not source_sas:
-            source_sas = create_short_lived_container_sas(cmd, source_client.account_name, source_client.account_key,
-                                                          source_container)
-
         # pylint: disable=inconsistent-return-statements
         def action_blob_copy(blob_name):
             if dryrun:
                 logger.warning('  - copy blob %s', blob_name)
             else:
-                return _create_file_and_directory_from_blob(client, source_client, destination_share, source_container,
+                return _create_file_and_directory_from_blob(cmd, client, source_client, share_name, source_container,
                                                             source_sas, blob_name, destination_dir=destination_path,
                                                             metadata=metadata, timeout=timeout,
                                                             existing_dirs=existing_dirs)
@@ -273,31 +299,23 @@ def storage_file_copy_batch(cmd, client, source_client, destination_share=None,
     if source_share:
         # copy files from share to share
 
-        # if the source client is None, assume the file share is in the same storage account as
-        # destination, therefore client is reused.
-        source_client = source_client or client
-
         # the cache of existing directories in the destination file share. the cache helps to avoid
         # repeatedly create existing directory so as to optimize the performance.
         existing_dirs = set([])
 
-        if not source_sas:
-            source_sas = create_short_lived_share_sas(cmd, source_client.account_name, source_client.account_key,
-                                                      source_share)
-
         # pylint: disable=inconsistent-return-statements
         def action_file_copy(file_info):
             dir_name, file_name = file_info
             if dryrun:
                 logger.warning('  - copy file %s', os.path.join(dir_name, file_name))
             else:
-                return _create_file_and_directory_from_file(client, source_client, destination_share, source_share,
+                return _create_file_and_directory_from_file(cmd, client, source_client, share_name, source_share,
                                                             source_sas, dir_name, file_name,
                                                             destination_dir=destination_path, metadata=metadata,
                                                             timeout=timeout, existing_dirs=existing_dirs)
 
         return list(filter_none(
-            action_file_copy(file) for file in collect_files(cmd, source_client, source_share, pattern)))
+            action_file_copy(file) for file in collect_files_track2(source_client, source_share, pattern)))
     # won't happen, the validator should ensure either source_container or source_share is set
     raise ValueError('Fail to find source. Neither blob container or file share is specified.')
 
@@ -317,7 +335,6 @@ def storage_file_delete_batch(cmd, client, source, pattern=None, dryrun=False, t
     source_files = list(glob_files_remotely(cmd, client, source, pattern))
 
     if dryrun:
-        logger = get_logger(__name__)
         logger.warning('delete files from %s', source)
         logger.warning('    pattern %s', pattern)
         logger.warning('      share %s', source)
@@ -331,7 +348,7 @@ def storage_file_delete_batch(cmd, client, source, pattern=None, dryrun=False, t
         delete_action(f)
 
 
-def _create_file_and_directory_from_blob(file_service, blob_service, share, container, sas, blob_name,
+def _create_file_and_directory_from_blob(cmd, file_service, blob_service, share, container, sas, blob_name,
                                          destination_dir=None, metadata=None, timeout=None, existing_dirs=None):
     """
     Copy a blob to file share and create the directory if needed.
@@ -339,15 +356,19 @@ def _create_file_and_directory_from_blob(file_service, blob_service, share, cont
     from azure.common import AzureException
     from azure.cli.command_modules.storage.util import normalize_blob_file_path
 
-    blob_url = blob_service.make_blob_url(container, encode_for_url(blob_name), sas_token=sas)
+    t_blob_client = cmd.get_models('_blob_client#BlobClient', resource_type=ResourceType.DATA_STORAGE_BLOB)
+    source_client = t_blob_client(account_url=blob_service.url, container_name=container,
+                                  blob_name=blob_name, credential=sas)
+    blob_url = source_client.url
+
     full_path = normalize_blob_file_path(destination_dir, blob_name)
-    file_name = os.path.basename(full_path)
     dir_name = os.path.dirname(full_path)
-    _make_directory_in_files_share(file_service, share, dir_name, existing_dirs)
+    _make_directory_in_files_share(file_service, share, dir_name, existing_dirs, V2=True)
 
     try:
-        file_service.copy_file(share, dir_name, file_name, blob_url, metadata, timeout)
-        return file_service.make_file_url(share, dir_name, file_name)
+        file_client = file_service.get_file_client(full_path)
+        file_client.start_copy_from_url(source_url=blob_url, metadata=metadata, timeout=timeout)
+        return file_client.url
     except AzureException:
         error_template = 'Failed to copy blob {} to file share {}. Please check if you have permission to read ' \
                          'source or set a correct sas token.'
@@ -355,27 +376,32 @@ def _create_file_and_directory_from_blob(file_service, blob_service, share, cont
         raise CLIError(error_template.format(blob_name, share))
 
 
-def _create_file_and_directory_from_file(file_service, source_file_service, share, source_share, sas, source_file_dir,
-                                         source_file_name, destination_dir=None, metadata=None, timeout=None,
-                                         existing_dirs=None):
+def _create_file_and_directory_from_file(cmd, file_service, source_file_service, share, source_share, sas,
+                                         source_file_dir, source_file_name, destination_dir=None, metadata=None,
+                                         timeout=None, existing_dirs=None):
     """
     Copy a file from one file share to another
     """
     from azure.common import AzureException
     from azure.cli.command_modules.storage.util import normalize_blob_file_path
 
-    file_url, source_file_dir, source_file_name = make_encoded_file_url_and_params(source_file_service, source_share,
-                                                                                   source_file_dir, source_file_name,
-                                                                                   sas_token=sas)
+    file_path = source_file_name
+    if source_file_dir:
+        file_path = source_file_dir + '/' + file_path
+    t_file_client = cmd.get_models('_file_client#ShareFileClient', resource_type=ResourceType.DATA_STORAGE_FILESHARE)
+    source_client = t_file_client(account_url=source_file_service.url, share_name=source_share, file_path=file_path,
+                                  credential=sas)
+    file_url = source_client.url
 
     full_path = normalize_blob_file_path(destination_dir, os.path.join(source_file_dir, source_file_name))
     file_name = os.path.basename(full_path)
     dir_name = os.path.dirname(full_path)
-    _make_directory_in_files_share(file_service, share, dir_name, existing_dirs)
+    _make_directory_in_files_share(file_service, share, dir_name, existing_dirs, V2=True)
 
     try:
-        file_service.copy_file(share, dir_name, file_name, file_url, metadata, timeout)
-        return file_service.make_file_url(share, dir_name or None, file_name)
+        file_client = file_service.get_file_client(full_path)
+        file_client.start_copy_from_url(source_url=file_url, metadata=metadata, timeout=timeout)
+        return file_client.url
     except AzureException:
         error_template = 'Failed to copy file {} from share {} to file share {}. Please check if ' \
                          'you have right permission to read source or set a correct sas token.'
@@ -383,10 +409,9 @@ def _create_file_and_directory_from_file(file_service, source_file_service, shar
         raise CLIError(error_template.format(file_name, source_share, share))
 
 
-def _make_directory_in_files_share(file_service, file_share, directory_path, existing_dirs=None):
+def _make_directory_in_files_share(file_service, file_share, directory_path, existing_dirs=None, V2=False):
     """
     Create directories recursively.
-
     This method accept a existing_dirs set which serves as the cache of existing directory. If the
     parameter is given, the method will search the set first to avoid repeatedly create directory
     which already exists.
@@ -407,7 +432,12 @@ def _make_directory_in_files_share(file_service, file_share, directory_path, exi
             continue
 
         try:
-            file_service.create_directory(share_name=file_share, directory_name=dir_name, fail_on_exist=False)
+            if V2:
+                file_service.create_directory(directory_name=dir_name)
+            else:
+                file_service.create_directory(share_name=file_share, directory_name=dir_name, fail_on_exist=False)
+        except ResourceExistsError:
+            pass
         except AzureHttpError:
             from knack.util import CLIError
             raise CLIError('Failed to create directory {}'.format(dir_name))
@@ -417,9 +447,38 @@ def _make_directory_in_files_share(file_service, file_share, directory_path, exi
 
 
 def _file_share_exists(client, resource_group_name, account_name, share_name):
-    from azure.core.exceptions import HttpResponseError
     try:
         file_share = client.get(resource_group_name, account_name, share_name, expand=None)
         return file_share is not None
     except HttpResponseError:
         return False
+
+
+# pylint: disable=redefined-builtin
+def generate_sas_file(cmd, client, directory_name=None, file_name=None, permission=None, expiry=None, start=None,
+                      id=None, ip=None, protocol=None, **kwargs):
+    t_generate_file_sas = get_sdk(cmd.cli_ctx, ResourceType.DATA_STORAGE_FILESHARE,
+                                  '_shared_access_signature#generate_file_sas')
+    file_path = file_name
+    if directory_name:
+        file_path = directory_name + '/' + file_path
+    file_path = file_path.split('/')
+    sas_token = t_generate_file_sas(account_name=client.account_name, share_name=client.share_name, file_path=file_path,
+                                    account_key=client.credential.account_key, permission=permission, expiry=expiry,
+                                    start=start, policy_id=id, ip=ip, protocol=protocol, **kwargs)
+    from urllib.parse import quote
+    return quote(sas_token, safe='&%()$=\',~')
+
+
+def file_exists(client, **kwargs):
+    try:
+        res = client.get_file_properties(**kwargs)
+        return bool(res)
+    except ResourceNotFoundError:
+        return False
+    except HttpResponseError as ex:
+        raise ex
+
+
+def file_updates(client, **kwargs):
+    return client.set_http_headers(**kwargs)
