@@ -226,6 +226,8 @@ def load_arguments(self, _):
                    arg_group=storage_arg_group,
                    help='The Storage Account Type.',
                    arg_type=get_enum_type(['GRS', 'LRS']))
+        c.argument('collation',
+                   help='Collation defines the rules that sort and compare data, and cannot be changed after SQL pool creation. The default collation is "SQL_Latin1_General_CP1_CI_AS".')
 
     with self.argument_context('synapse sql pool update') as c:
         c.argument('sku_name', options_list=['--performance-level'], help='The performance level.')
@@ -1098,3 +1100,38 @@ def load_arguments(self, _):
         c.argument('workspace_name', arg_type=workspace_name_arg_type, help='The name of the workspace')
         c.argument('output_folder', type=str, help='The name of the output folder')
         c.argument('script_name', arg_type=name_type, help='The name of the KQL script.')
+
+    # synapse link connections
+    with self.argument_context('synapse link-connection list') as c:
+        c.argument('workspace_name', arg_type=workspace_name_arg_type)
+
+    for scope in ['create', 'update']:
+        with self.argument_context('synapse link-connection ' + scope) as c:
+            c.argument('workspace_name', arg_type=workspace_name_arg_type)
+            c.argument('link_connection_name', arg_type=name_type, help='The link connection name.')
+            c.argument('definition_file', arg_type=definition_file_arg_type)
+
+    for scope in ['show', 'delete', 'get-status', 'start', 'stop']:
+        with self.argument_context('synapse link-connection ' + scope) as c:
+            c.argument('workspace_name', arg_type=workspace_name_arg_type)
+            c.argument('link_connection_name', arg_type=name_type, help='The link connection name.')
+
+    with self.argument_context('synapse link-connection list-link-tables') as c:
+        c.argument('workspace_name', arg_type=workspace_name_arg_type)
+        c.argument('link_connection_name', arg_type=name_type, help='The link connection name.')
+
+    with self.argument_context('synapse link-connection edit-link-tables') as c:
+        c.argument('workspace_name', arg_type=workspace_name_arg_type)
+        c.argument('link_connection_name', arg_type=name_type, help='The link connection name.')
+        c.argument('definition_file', arg_type=definition_file_arg_type, options_list=['--file', '-f'], type=shell_safe_json_parse,
+                   help='The Edit link-tables file path, The file format can be viewed using --help.')
+
+    with self.argument_context('synapse link-connection get-link-tables-status') as c:
+        c.argument('workspace_name', arg_type=workspace_name_arg_type)
+        c.argument('link_connection_name', arg_type=name_type, help='The link connection name.')
+        c.argument('max_segment_count', help='Max segment count to query table status.')
+        c.argument('continuation_token', help='Continuation token to query table status.')
+    with self.argument_context('synapse link-connection update-landing-zone-credential') as c:
+        c.argument('workspace_name', arg_type=workspace_name_arg_type)
+        c.argument('link_connection_name', arg_type=name_type, help='The link connection name.')
+        c.argument('sas_token', help='Value of secure string.')
