@@ -21,9 +21,10 @@ except ImportError:
 from knack.util import CLIError
 from knack.log import get_logger
 
-from msrestazure.azure_exceptions import CloudError
 from msrestazure.tools import is_valid_resource_id, resource_id, parse_resource_id
 
+from azure.core.exceptions import HttpResponseError
+
 from azure.cli.core.commands import cached_get, cached_put
 from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.core.commands.validators import get_default_location_from_resource_group, validate_tags
@@ -55,6 +56,16 @@ class ScriptType(Enum):
     FILE = "file"
 
 
+class GalleryImageReferenceType(Enum):
+    COMPUTE = (0, 'id')
+    COMMUNITY = (1, 'communityGalleryImageId')
+    SHARED = (2, 'sharedGalleryImageId')
+
+    def __init__(self, index, backend_key):
+        self.index = index
+        self.backend_key = backend_key
+
+
 # region Client Factories
 
 def image_builder_client_factory(cli_ctx, _):
@@ -281,7 +292,7 @@ def process_image_template_create_namespace(cmd, namespace):  # pylint: disable=
             }
 
             logger.info("%s, looks like a managed image name. Using resource ID: %s", image_name, namespace.source)  # pylint: disable=line-too-long
-        except CloudError:
+        except HttpResponseError:
             pass
 
     if not source:
