@@ -302,7 +302,8 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
         encryption_at_host=None, dedicated_host_group=None, enable_auto_update=None, patch_mode=None,
         enable_hotpatching=None, platform_fault_domain=None, security_type=None, enable_secure_boot=None,
         enable_vtpm=None, count=None, edge_zone=None, os_disk_delete_option=None, user_data=None,
-        capacity_reservation_group=None, enable_hibernation=None, v_cpus_available=None, v_cpus_per_core=None):
+        capacity_reservation_group=None, enable_hibernation=None, v_cpus_available=None, v_cpus_per_core=None,
+        os_disk_security_encryption_type=None, os_disk_secure_vm_disk_encryption_set=None):
 
     os_caching = disk_info['os'].get('caching')
 
@@ -492,6 +493,48 @@ def build_vm_resource(  # pylint: disable=too-many-locals, too-many-statements,
             storage_profiles['CommunityGalleryImage']['osDisk']['managedDisk']['diskEncryptionSet'] = {
                 'id': os_disk_encryption_set,
             }
+        if os_disk_security_encryption_type is not None:
+            storage_profiles['ManagedPirImage']['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type,
+                }
+            })
+            storage_profiles['ManagedCustomImage']['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type,
+                }
+            })
+            storage_profiles['SharedGalleryImage']['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type,
+                }
+            })
+            storage_profiles['CommunityGalleryImage']['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type,
+                }
+            })
+            if os_disk_secure_vm_disk_encryption_set is not None:
+                storage_profiles['ManagedPirImage']['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
+                storage_profiles['ManagedCustomImage']['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
+                storage_profiles['SharedGalleryImage']['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
+                storage_profiles['CommunityGalleryImage']['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
 
         profile = storage_profiles[storage_profile.name]
         if os_disk_size_gb:
@@ -867,7 +910,8 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
                         enable_spot_restore=None, spot_restore_timeout=None, capacity_reservation_group=None,
                         enable_auto_update=None, patch_mode=None, enable_agent=None, security_type=None,
                         enable_secure_boot=None, enable_vtpm=None, automatic_repairs_action=None, v_cpus_available=None,
-                        v_cpus_per_core=None):
+                        v_cpus_per_core=None, os_disk_security_encryption_type=None,
+                        os_disk_secure_vm_disk_encryption_set=None):
 
     # Build IP configuration
     ip_configuration = {}
@@ -944,6 +988,18 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
             storage_properties['osDisk']['managedDisk']['diskEncryptionSet'] = {
                 'id': os_disk_encryption_set
             }
+        if os_disk_security_encryption_type is not None:
+            storage_properties['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type
+                }
+            })
+            if os_disk_secure_vm_disk_encryption_set is not None:
+                storage_properties['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
         if disk_info and disk_info['os'].get('diffDiskSettings'):
             storage_properties['osDisk']['diffDiskSettings'] = disk_info['os']['diffDiskSettings']
 
@@ -975,6 +1031,18 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
             storage_properties['osDisk']['managedDisk']['diskEncryptionSet'] = {
                 'id': os_disk_encryption_set
             }
+        if os_disk_security_encryption_type is not None:
+            storage_properties['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type,
+                }
+            })
+            if os_disk_secure_vm_disk_encryption_set is not None:
+                storage_properties['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
     if storage_profile == StorageProfile.CommunityGalleryImage:
         storage_properties['osDisk'] = {
             'caching': os_caching,
@@ -989,6 +1057,18 @@ def build_vmss_resource(cmd, name, computer_name_prefix, location, tags, overpro
             storage_properties['osDisk']['managedDisk']['diskEncryptionSet'] = {
                 'id': os_disk_encryption_set
             }
+        if os_disk_security_encryption_type is not None:
+            storage_properties['osDisk']['managedDisk'].update({
+                'securityProfile': {
+                    'securityEncryptionType': os_disk_security_encryption_type,
+                }
+            })
+            if os_disk_secure_vm_disk_encryption_set is not None:
+                storage_properties['osDisk']['managedDisk']['securityProfile'].update({
+                    'diskEncryptionSet': {
+                        'id': os_disk_secure_vm_disk_encryption_set
+                    }
+                })
 
     if disk_info:
         data_disks = [v for k, v in disk_info.items() if k != 'os']
