@@ -17,7 +17,7 @@ except ImportError:
     logger.warn("Wheel is not available, disabling bdist_wheel hook")
     cmdclass = {}
 
-VERSION = "2.36.0"
+VERSION = "2.38.0"
 # If we have source, validate that our version numbers match
 # This should prevent uploading releases with mismatched versions.
 try:
@@ -51,12 +51,12 @@ CLASSIFIERS = [
 ]
 
 DEPENDENCIES = [
-    'antlr4-python3-runtime~=4.7.2',
+    "antlr4-python3-runtime~=4.9.3",
     'azure-appconfiguration~=1.1.1',
     'azure-batch~=12.0.0',
     'azure-cli-core=={}'.format(VERSION),
     'azure-cosmos~=3.0,>=3.0.2',
-    'azure-data-tables==12.2.0',
+    'azure-data-tables==12.4.0',
     'azure-datalake-store~=0.0.49',
     'azure-graphrbac~=0.60.0',
     'azure-keyvault-administration==4.0.0b3',
@@ -65,21 +65,21 @@ DEPENDENCIES = [
     'azure-loganalytics~=0.1.0',
     'azure-mgmt-advisor==9.0.0',
     'azure-mgmt-apimanagement~=3.0.0',
-    'azure-mgmt-appconfiguration==2.1.0b2',
+    'azure-mgmt-appconfiguration==2.1.0',
     'azure-mgmt-applicationinsights~=1.0.0',
     'azure-mgmt-authorization~=0.61.0',
     'azure-mgmt-batchai==7.0.0b1',
     'azure-mgmt-batch~=16.1.0',
     'azure-mgmt-billing==6.0.0',
-    'azure-mgmt-botservice~=0.3.0',
+    'azure-mgmt-botservice~=2.0.0b3',
     'azure-mgmt-cdn==12.0.0',
-    'azure-mgmt-cognitiveservices~=13.1.0',
-    'azure-mgmt-compute~=26.1.0',
+    'azure-mgmt-cognitiveservices~=13.2.0',
+    'azure-mgmt-compute~=27.1.0',
     'azure-mgmt-consumption~=2.0',
     'azure-mgmt-containerinstance~=9.1.0',
     'azure-mgmt-containerregistry==8.2.0',
-    'azure-mgmt-containerservice~=19.0.0',
-    'azure-mgmt-cosmosdb==7.0.0b2',
+    'azure-mgmt-containerservice~=19.1.0',
+    'azure-mgmt-cosmosdb==7.0.0b6',
     'azure-mgmt-databoxedge~=1.0.0',
     'azure-mgmt-datalake-analytics~=0.2.1',
     'azure-mgmt-datalake-store~=0.5.0',
@@ -88,11 +88,11 @@ DEPENDENCIES = [
     'azure-mgmt-devtestlabs~=4.0',
     'azure-mgmt-dns~=8.0.0',
     'azure-mgmt-eventgrid==9.0.0',
-    'azure-mgmt-eventhub~=9.1.0',
+    'azure-mgmt-eventhub~=10.1.0',
     'azure-mgmt-extendedlocation==1.0.0b2',
     'azure-mgmt-hdinsight~=9.0.0',
     'azure-mgmt-imagebuilder~=1.0.0',
-    'azure-mgmt-iotcentral~=9.0.0',
+    'azure-mgmt-iotcentral~=10.0.0b1',
     'azure-mgmt-iothub==2.2.0',
     'azure-mgmt-iothubprovisioningservices==1.1.0',
     'azure-mgmt-keyvault==9.3.0',
@@ -104,36 +104,36 @@ DEPENDENCIES = [
     'azure-mgmt-marketplaceordering==1.1.0',
     'azure-mgmt-media~=9.0',
     'azure-mgmt-monitor~=3.0.0',
-    'azure-mgmt-msi~=6.0.0',
-    'azure-mgmt-netapp~=7.0.0',
-    'azure-mgmt-network~=19.3.0',
-    'azure-mgmt-policyinsights~=1.0.0',
+    'azure-mgmt-msi~=6.0.1',
+    'azure-mgmt-netapp~=8.0.0',
+    'azure-mgmt-network~=20.0.0',
+    'azure-mgmt-policyinsights~=1.1.0b2',
     'azure-mgmt-privatedns~=1.0.0',
     'azure-mgmt-rdbms~=10.0.0',
-    'azure-mgmt-recoveryservicesbackup~=4.1.1',
+    'azure-mgmt-recoveryservicesbackup~=5.0.0',
     'azure-mgmt-recoveryservices~=2.0.0',
-    'azure-mgmt-redhatopenshift==1.0.0',
+    'azure-mgmt-redhatopenshift==1.1.0',
     'azure-mgmt-redis~=13.1.0',
     'azure-mgmt-relay~=0.1.0',
-    'azure-mgmt-reservations==0.6.0',  # TODO: Use requirements.txt instead of '==' #9781
-    'azure-mgmt-resource==20.0.0',
+    'azure-mgmt-reservations==2.0.0',  # TODO: Use requirements.txt instead of '==' #9781
+    'azure-mgmt-resource==21.1.0b1',
     'azure-mgmt-search~=8.0',
     'azure-mgmt-security==2.0.0b1',
     'azure-mgmt-servicebus~=7.1.0',
     'azure-mgmt-servicefabricmanagedclusters~=1.0.0',
-    'azure-mgmt-servicelinker==1.0.0b2',
+    'azure-mgmt-servicelinker==1.0.0',
     'azure-mgmt-servicefabric~=1.0.0',
     'azure-mgmt-signalr==1.0.0b2',
-    'azure-mgmt-sqlvirtualmachine==1.0.0b2',
-    'azure-mgmt-sql==4.0.0b1',
+    'azure-mgmt-sqlvirtualmachine==1.0.0b3',
+    'azure-mgmt-sql==4.0.0b2',
     'azure-mgmt-storage~=20.0.0',
     'azure-mgmt-synapse==2.1.0b2',
     'azure-mgmt-trafficmanager~=1.0.0',
     'azure-mgmt-web~=6.1.0',
-    'azure-multiapi-storage~=0.8.0',
+    'azure-multiapi-storage~=0.9.0',
     'azure-storage-common~=1.4',
     'azure-synapse-accesscontrol~=0.5.0',
-    'azure-synapse-artifacts~=0.12.0',
+    'azure-synapse-artifacts~=0.13.0',
     'azure-synapse-managedprivateendpoints~=0.3.0',
     'azure-synapse-spark~=0.2.0',
     'chardet~=3.0.4',
@@ -142,10 +142,10 @@ DEPENDENCIES = [
     'distro; sys_platform == "linux"',
     'fabric~=2.4',
     'javaproperties~=0.5.1',
-    'jsondiff~=1.3.0',
+    'jsondiff~=2.0.0',
     'packaging>=20.9,<22.0',
     'PyGithub~=1.38',
-    'PyNaCl~=1.4.0',
+    'PyNaCl~=1.5.0',
     'scp~=0.13.2',
     'semver==2.13.0',
     'six>=1.10.0',  # six is still used by countless extensions
